@@ -42,6 +42,7 @@
 // Local includes
 
 #include "albuminfo.h"
+#include "databaseparameters.h"
 #include "digikam_export.h"
 
 class QDate;
@@ -107,7 +108,7 @@ public:
     * A return value of false during startup indicates termination of the program
     * (user is informed)
     */
-    bool setDatabase(const QString& dbPath, bool priority, const QString& suggestedAlbumRoot = QString());
+    bool setDatabase(const DatabaseParameters& params, bool priority, const QString suggestedAlbumRoot = QString());
 
     /** Some checks for settings done in first run wizard */
     static void checkDatabaseDirsAfterFirstRun(const QString& dbPath, const QString& albumPath);
@@ -117,7 +118,7 @@ public:
     * Handles user notification about problems.
     * Call this instead of setDatabase when digikam is up and running.
     */
-    void changeDatabase(const QString& dbPath);
+    void changeDatabase(const DatabaseParameters& params);
 
     /**
     * Stop ongoing operations, prepare for application shutdown
@@ -127,7 +128,7 @@ public:
     /**
     * Checks if the given database path is equal to the current one
     */
-    bool databaseEqual(const QString& dbPath) const;
+    bool databaseEqual(const QString& dbType, const QString& dbName, const QString& dbHostName, int dbPort, bool dbInternalServer) const;
 
     /**
     * starts scanning the libraryPath and listing the albums. If the
@@ -186,6 +187,16 @@ public:
     * @returns the current album
     */
     Album*    currentAlbum() const;
+
+    /**
+     * @returns the current PAlbum or null if no one is selected
+     */
+    PAlbum* currentPAlbum() const;
+
+    /**
+     * @returns the current TAlbum or null if no one is selected
+     */
+    TAlbum* currentTAlbum() const;
     //@}
 
     /** @name Finding Albums
@@ -462,16 +473,55 @@ public:
     bool deleteSAlbum(SAlbum* album);
     //@}
 
+    /** @name Accessors to counting maps
+     */
+    //@{
+
+    /**
+     * Returns the latest count for PAlbums as also emitted via
+     * signalPAlbumsDirty.
+     *
+     * @return count map for PAlbums
+     */
+    QMap<int, int> getPAlbumsCount() const;
+
+    /**
+     * Returns the latest count for TAlbums as also emitted via
+     * signalTAlbumsDirty.
+     *
+     * @return count map for TAlbums
+     */
+    QMap<int, int> getTAlbumsCount() const;
+
+    /**
+     * Returns the latest count for DAlbums as also emitted via
+     * signalDAlbumsDirty.
+     *
+     * @return count map for DAlbums
+     */
+    QMap<YearMonth, int> getDAlbumsCount() const;
+
+    /**
+     * Returns if the given album is currently being moved, that is,
+     * if this album is in between signalAlbumAboutToBeMoved and
+     * signalAlbumMoved. In this case, you can preserve state of such an album
+     * because the object is guaranteed not to be deleted, even if
+     * signalAlbumAboutToBeDeleted is emitted.
+     */
+    bool isMovingAlbum(Album* album) const;
+
+    //@}
+
 Q_SIGNALS:
 
     /// An album is about to be added to the given parent (0 if album is root)
     /// after the item given by prev (prev is 0 if parent has no children yet)
     void signalAlbumAboutToBeAdded(Album *album, Album *parent, Album *prev);
-    /// The album has been added
+    /// The album has been added.
     void signalAlbumAdded(Album* album);
-    /// The album is about to be deleted, but is still fully valid
+    /// The album is about to be deleted, but is still fully valid.
     void signalAlbumAboutToBeDeleted(Album *album);
-    /// The album is deleted, but the object can still be accessed
+    /// The album is deleted, but the object can still be accessed.
     void signalAlbumDeleted(Album* album);
     /// The album is deleted, the object can no longer be accessed.
     /// For identification purposes, the former album pointer is passed.
@@ -483,7 +533,12 @@ Q_SIGNALS:
     void signalAlbumIconChanged(Album* album);
     void signalAlbumRenamed(Album* album);
     void signalSearchUpdated(SAlbum *album);
-    void signalTAlbumMoved(TAlbum* album, TAlbum* newParent);
+    /// Indicates that an album is about to be moved. Signals for deleting and adding will be
+    /// sent afterwards, but the album object is guaranteed not to be deleted until after signalAlbumMoved.
+    void signalAlbumAboutToBeMoved(Album* album);
+    /// Emitted when the album is moved to its new parent. After signalAlbumAboutToBeMoved,
+    /// all four signals for first deleting and then adding will have been sent.
+    void signalAlbumMoved(Album* album);
     void signalPAlbumsDirty(const QMap<int, int>&);
     void signalTAlbumsDirty(const QMap<int, int>&);
     void signalDAlbumsDirty(const QMap<YearMonth, int>&);
@@ -513,20 +568,20 @@ private Q_SLOTS:
     /**
      * Scan albums directly from database and creates new PAlbums
      * It only creates those PAlbums which haven't already been
-     * created
+     * created.
      */
     void scanPAlbums();
     void updateChangedPAlbums();
     /**
      * Scan tags directly from database and creates new TAlbums
      * It only creates those TAlbums which haven't already been
-     * created
+     * created.
      */
     void scanTAlbums();
     /**
      * Scan searches directly from database and creates new SAlbums
      * It only creates those SAlbums which haven't already been
-     * created
+     * created.
      */
     void scanSAlbums();
     /**
@@ -544,6 +599,16 @@ private:
     AlbumManager();
     ~AlbumManager();
 
+    /**
+     * Checks whether an Album has a direct child with the given name.
+     *
+     * @param parent album to check children for
+     * @param title title to search for
+     * @return <code>true</code> if there is a child with name, else
+     *         <code>false</code>
+     */
+    bool hasDirectChildAlbumWithTitle(Album *parent, const QString &title);
+
     void insertPAlbum(PAlbum *album, PAlbum *parent);
     void removePAlbum(PAlbum *album);
     void insertTAlbum(TAlbum *album, TAlbum *parent);
