@@ -59,13 +59,13 @@ class AlbumSelectTreeViewPriv
 {
 public:
     AlbumSelectTreeViewPriv() :
-        albumModificationHelper(0)
+        albumModificationHelper(0),
+        newAlbumAction(0)
     {
     }
 
-    AlbumModificationHelper *albumModificationHelper;
-
-    KAction *newAlbumAction;
+    AlbumModificationHelper* albumModificationHelper;
+    KAction*                 newAlbumAction;
 
 };
 
@@ -133,14 +133,14 @@ public:
     {
     }
 
-    AlbumModel          *albumModel;
-    AlbumSelectTreeView *albumTreeView;
+    AlbumModel*              albumModel;
+    AlbumSelectTreeView*     albumTreeView;
 
-    AlbumModificationHelper *albumModificationHelper;
+    AlbumModificationHelper* albumModificationHelper;
 
-    SearchTextBar *searchBar;
+    SearchTextBar*           searchBar;
 
-    KPushButton   *newAlbumBtn;
+    KPushButton*             newAlbumBtn;
 };
 
 AlbumSelectWidget::AlbumSelectWidget(QWidget *parent, PAlbum* albumToSelect)
