@@ -7,6 +7,7 @@
  * Description : Tree View for album models
  *
  * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -65,7 +66,9 @@ static QList<A*> selectedAlbums(QItemSelectionModel *selModel, AlbumFilterModel
     QList<QModelIndex> indexes = selModel->selectedIndexes();
     QList<A*> albums;
     foreach (const QModelIndex& index, indexes)
+    {
         albums << static_cast<A*>(filterModel->albumForIndex(index));
+    }
     return albums;
 }
 
@@ -131,11 +134,6 @@ public:
         selectOnContextMenu(true),
         enableContextMenu(false),
         setInAlbumManager(false),
-        configSelectionEntry("Selection"),
-        configExpansionEntry("Expansion"),
-        configCurrentIndexEntry("CurrentIndex"),
-        configSortColumnEntry("SortColumn"),
-        configSortOrderEntry("SortOrder"),
         resizeColumnsTimer(0)
     {
     }
@@ -149,20 +147,27 @@ public:
     bool enableContextMenu;
     bool setInAlbumManager;
 
-    QMap<int, State> statesByAlbumId;
-    QMap<int, State> searchBackup;
+    QMap<int, State>     statesByAlbumId;
+    QMap<int, State>     searchBackup;
 
-    const QString configSelectionEntry;
-    const QString configExpansionEntry;
-    const QString configCurrentIndexEntry;
-    const QString configSortColumnEntry;
-    const QString configSortOrderEntry;
+    static const QString configSelectionEntry;
+    static const QString configExpansionEntry;
+    static const QString configCurrentIndexEntry;
+    static const QString configSortColumnEntry;
+    static const QString configSortOrderEntry;
 
     QTimer       *resizeColumnsTimer;
 
-    AlbumPointer<Album> lastSelectedAlbum;
+    AlbumPointer<Album>  lastSelectedAlbum;
 
 };
+const QString AbstractAlbumTreeViewPriv::configSelectionEntry("Selection");
+const QString AbstractAlbumTreeViewPriv::configExpansionEntry("Expansion");
+const QString AbstractAlbumTreeViewPriv::configCurrentIndexEntry("CurrentIndex");
+const QString AbstractAlbumTreeViewPriv::configSortColumnEntry("SortColumn");
+const QString AbstractAlbumTreeViewPriv::configSortOrderEntry("SortOrder");
+
+// --------------------------------------------------------
 
 AbstractAlbumTreeView::AbstractAlbumTreeView(AbstractSpecificAlbumModel *model, AlbumFilterModel *filterModel, QWidget *parent)
     : QTreeView(parent), StateSavingObject(this),
@@ -962,18 +967,23 @@ class AbstractCheckableAlbumTreeViewPriv
 {
 public:
 
-    AbstractCheckableAlbumTreeViewPriv() :
-        configCheckedAlbumsEntry("Checked"),
-        configRestoreCheckedEntry("RestoreChecked")
+    AbstractCheckableAlbumTreeViewPriv()
     {
     }
 
-    const QString configCheckedAlbumsEntry;
-    const QString configRestoreCheckedEntry;
+    static const QString configCheckedAlbumsEntry;
+    static const QString configPartiallyCheckedAlbumsEntry;
+    static const QString configRestoreCheckedEntry;
 
-    QList<int> checkedAlbumIds;
+    QList<int>           checkedAlbumIds;
+    QList<int>           partiallyCheckedAlbumIds;
 
 };
+const QString AbstractCheckableAlbumTreeViewPriv::configCheckedAlbumsEntry("Checked");
+const QString AbstractCheckableAlbumTreeViewPriv::configPartiallyCheckedAlbumsEntry("PartiallyChecked");
+const QString AbstractCheckableAlbumTreeViewPriv::configRestoreCheckedEntry("RestoreChecked");
+
+// --------------------------------------------------------
 
 AbstractCheckableAlbumTreeView::AbstractCheckableAlbumTreeView(AbstractCheckableAlbumModel *model,
                                                                CheckableAlbumFilterModel *filterModel, QWidget *parent)
@@ -1017,8 +1027,34 @@ void AbstractCheckableAlbumTreeView::setCheckOnMiddleClick(bool doThat)
 
 void AbstractCheckableAlbumTreeView::middleButtonPressed(Album *a)
 {
-    if (static_cast<AbstractCheckableAlbumModel*>(m_albumModel)->isCheckable())
-        static_cast<AbstractCheckableAlbumModel*>(m_albumModel)->toggleChecked(a);
+    AbstractCheckableAlbumModel* model = static_cast<AbstractCheckableAlbumModel*>(m_albumModel);
+    if (!model)
+    {
+        return;
+    }
+
+    if (model->isCheckable())
+    {
+        if (model->isTristate())
+        {
+            switch (model->checkState(a))
+            {
+                case Qt::Unchecked:
+                    model->setCheckState(a, Qt::PartiallyChecked);
+                    break;
+                case Qt::PartiallyChecked:
+                    model->setCheckState(a, Qt::Checked);
+                    break;
+                case Qt::Checked:
+                    model->setCheckState(a, Qt::Unchecked);
+                    break;
+            }
+        }
+        else
+        {
+            model->toggleChecked(a);
+        }
+    }
 }
 
 bool AbstractCheckableAlbumTreeView::isRestoreCheckState() const
@@ -1048,7 +1084,7 @@ void AbstractCheckableAlbumTreeView::doLoadState()
                     d->configCheckedAlbumsEntry), QStringList());
 
     d->checkedAlbumIds.clear();
-    foreach(const QString &albumId, checkedAlbums)
+    foreach(const QString& albumId, checkedAlbums)
     {
         bool ok;
         int id = albumId.toInt(&ok);
@@ -1058,6 +1094,20 @@ void AbstractCheckableAlbumTreeView::doLoadState()
         }
     }
 
+    QStringList partiallyCheckedAlbums = group.readEntry(entryName(
+                    d->configPartiallyCheckedAlbumsEntry), QStringList());
+
+    d->partiallyCheckedAlbumIds.clear();
+    foreach(const QString& albumId, partiallyCheckedAlbums)
+    {
+        bool ok;
+        int id = albumId.toInt(&ok);
+        if (ok)
+        {
+            d->partiallyCheckedAlbumIds << id;
+        }
+    }
+
     // initially sync with the albums that are already in the model
     restoreCheckStateForHierarchy(QModelIndex());
 }
@@ -1089,11 +1139,21 @@ void AbstractCheckableAlbumTreeView::restoreCheckStateForHierarchy(const QModelI
 void AbstractCheckableAlbumTreeView::restoreCheckState(const QModelIndex &index)
 {
     Album *album = checkableModel()->albumForIndex(index);
-    if (album && d->checkedAlbumIds.contains(album->id()))
+    if (!album)
+    {
+        return;
+    }
+
+    if (d->checkedAlbumIds.contains(album->id()))
     {
         checkableModel()->setCheckState(album, Qt::Checked);
         d->checkedAlbumIds.removeOne(album->id());
     }
+    if (d->partiallyCheckedAlbumIds.contains(album->id()))
+    {
+        checkableModel()->setCheckState(album, Qt::PartiallyChecked);
+        d->partiallyCheckedAlbumIds.removeOne(album->id());
+    }
 }
 
 void AbstractCheckableAlbumTreeView::doSaveState()
@@ -1118,6 +1178,20 @@ void AbstractCheckableAlbumTreeView::doSaveState()
 
     group.writeEntry(entryName(d->configCheckedAlbumsEntry), checkedIds);
 
+    if (!checkableModel()->isTristate())
+    {
+        return;
+    }
+
+    QList<Album*> partiallyCheckedAlbums = checkableModel()->partiallyCheckedAlbums();
+    QStringList partiallyCheckedIds;
+    foreach(Album* album, partiallyCheckedAlbums)
+    {
+        partiallyCheckedIds << QString::number(album->id());
+    }
+
+    group.writeEntry(entryName(d->configPartiallyCheckedAlbumsEntry), partiallyCheckedIds);
+
 }
 
 // --------------------------------------- //
