@@ -53,6 +53,7 @@
 #include "albummanager.h"
 #include "albumdb.h"
 #include "advancedrenamedialog.h"
+#include "advancedrenameprocessdialog.h"
 #include "albumsettings.h"
 #include "contextmenuhelper.h"
 #include "databaseaccess.h"
@@ -380,89 +381,24 @@ void DigikamImageView::setExifOrientationOfSelected(int orientation)
 
 void DigikamImageView::rename()
 {
-    if (!d->renameThread)
-    {
-        d->renameThread = new RenameThread(this);
-
-        connect(d->renameThread, SIGNAL(renameFile(const KUrl&, const QString&)),
-                d->utilities, SLOT(rename(const KUrl&, const QString&)));
-
-        connect(d->utilities, SIGNAL(imageRenameSucceeded(const KUrl&)),
-                d->renameThread, SLOT(slotSuccess(const KUrl&)));
-
-        connect(d->utilities, SIGNAL(imageRenameFailed(const KUrl&)),
-                d->renameThread, SLOT(slotFailed(const KUrl&)));
-
-        connect(d->utilities, SIGNAL(renamingAborted()),
-                d->renameThread, SLOT(cancel()));
-    }
-
     KUrl::List urls = selectedUrls();
+    NewNamesList newNamesList;
 
     QPointer<AdvancedRenameDialog> dlg = new AdvancedRenameDialog(this);
     dlg->slotAddImages(urls);
 
     if (dlg->exec() == KDialog::Accepted)
     {
-        NewNamesList newNamesList = dlg->newNames();
-
-/*
- * EXPERMINENTAL DIR CREATION / Turned off for now
- */
-//        we need to check if the destination folder(s) exist, if not, we ask the user if the folder should be created
-//        DatabaseAccess access;
-//
-//        foreach (NewNameInfo newNameInfo, newNamesList)
-//        {
-//            ImageInfo info(newNameInfo.first);
-//            KUrl _url = info.databaseUrl();
-//
-//            Digikam::DatabaseUrl dbUrlSrc(_url);
-//            _url.setFileName(newNameInfo.second);
-//            Digikam::DatabaseUrl dbUrlDst(_url);
-//
-//            int dstAlbumID = -1;
-//            dstAlbumID     = access.db()->getAlbumForPath(dbUrlDst.albumRootId(), dbUrlDst.album(), false);
-//
-//            if (dstAlbumID == -1)
-//            {
-//                // if the new file name contains slashes, split the string and create each album separately
-//                QFileInfo tmp(newNameInfo.second);
-//                QStringList albums2BeCreated = tmp.path().split(QRegExp("\\/+"), QString::SkipEmptyParts);
-//
-//                PAlbum *parentPAlbum = AlbumManager::instance()->findPAlbum(info.albumId());
-//                foreach (const QString &newAlbum, albums2BeCreated)
-//                {
-//                    PAlbum *newPAlbum = 0;
-//                    QString errorMsg;
-//
-//                    newPAlbum = AlbumManager::instance()->createPAlbum(parentPAlbum,
-//                                                                       newAlbum,
-//                                                                       QString(),
-//                                                                       QDate::currentDate(),
-//                                                                       QString(),
-//                                                                       errorMsg
-//                    );
-//
-//                    if (newPAlbum == 0)
-//                    {
-//                        KMessageBox::error(this, errorMsg, i18n("Error"));
-//                        return;
-//                    }
-//
-//                    // all operations went fine, set the new album as parent
-//                    parentPAlbum = newPAlbum;
-//                }
-//            }
-//        }
-
-        d->renameThread->addNewNames(newNamesList);
-        if (!d->renameThread->isRunning())
-        {
-            d->renameThread->start();
-        }
+        newNamesList = dlg->newNames();
     }
     delete dlg;
+
+    if (!newNamesList.isEmpty())
+    {
+        QPointer<AdvancedRenameProcessDialog> dlg = new AdvancedRenameProcessDialog(newNamesList);
+        dlg->exec();
+        delete dlg;
+    }
 }
 
 void DigikamImageView::slotRotateLeft()
@@ -474,7 +410,9 @@ void DigikamImageView::slotRotateLeft()
         foreach(QAction* ac, list)
         {
             if (ac->objectName() == QString("rotate_ccw"))
+            {
                 ac->trigger();
+            }
         }
     }
 }
@@ -488,7 +426,9 @@ void DigikamImageView::slotRotateRight()
         foreach(QAction* ac, list)
         {
             if (ac->objectName() == QString("rotate_cw"))
+            {
                 ac->trigger();
+            }
         }
     }
 }
