@@ -6,9 +6,10 @@
  * Date        : 2002-16-10
  * Description : implementation of album view interface.
  *
- * Copyright (C) 2002-2005 by Renchi Raju  <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2002-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Copyright (C) 2002-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (c) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
+ * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
+ * Copyright (C) 2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -51,6 +52,8 @@
 #include "imageviewutilities.h"
 #include "leftsidebarwidgets.h"
 #include "loadingcacheinterface.h"
+#include "globals.h"
+#include "metadatahub.h"
 #include "metadatamanager.h"
 #include "queuemgrwindow.h"
 #include "scancontroller.h"
@@ -67,75 +70,89 @@ class DigikamViewPriv
 {
 public:
 
-    DigikamViewPriv()
+    DigikamViewPriv() :
+        needDispatchSelection(false),
+        cancelSlideShow(false),
+        useAlbumHistory(false),
+        initialAlbumID(0),
+        thumbSize(ThumbnailSize::Medium),
+        dockArea(0),
+        splitter(0),
+        selectionTimer(0),
+        thumbSizeTimer(0),
+        albumFolderSideBar(0),
+        tagViewSideBar(0),
+        dateViewSideBar(0),
+        timelineSideBar(0),
+        searchSideBar(0),
+        fuzzySearchSideBar(0),
+#ifdef HAVE_MARBLEWIDGET
+        gpsSearchSideBar(0),
+#endif
+        parent(0),
+        iconView(0),
+        albumManager(0),
+        albumHistory(0),
+        albumWidgetStack(0),
+        albumModificationHelper(0),
+        tagModificationHelper(0),
+        searchModificationHelper(0),
+        leftSideBar(0),
+        rightSideBar(0),
+        tagFilterWidget(0),
+        optionAlbumViewPrefix("AlbumView"),
+        modelCollection(0)
     {
-        dockArea              = 0;
-        splitter              = 0;
-        parent                = 0;
-        iconView              = 0;
-        albumManager          = 0;
-        albumHistory          = 0;
-        leftSideBar           = 0;
-        rightSideBar          = 0;
-        albumWidgetStack      = 0;
-        selectionTimer        = 0;
-        thumbSizeTimer        = 0;
-        needDispatchSelection = false;
-        cancelSlideShow       = false;
-        useAlbumHistory       = false;
-        thumbSize             = ThumbnailSize::Medium;
-        optionAlbumViewPrefix = "AlbumView";
-        modelCollection       = 0;
     }
 
     QString userPresentableAlbumTitle(const QString& album);
 
-    bool                      needDispatchSelection;
-    bool                      cancelSlideShow;
-    bool                      useAlbumHistory;
+    bool                          needDispatchSelection;
+    bool                          cancelSlideShow;
+    bool                          useAlbumHistory;
 
-    int                       initialAlbumID;
-    int                       thumbSize;
+    int                           initialAlbumID;
+    int                           thumbSize;
 
-    QMainWindow*              dockArea;
+    QMainWindow*                  dockArea;
 
-    SidebarSplitter*          splitter;
+    SidebarSplitter*              splitter;
 
-    QTimer*                   selectionTimer;
-    QTimer*                   thumbSizeTimer;
+    QTimer*                       selectionTimer;
+    QTimer*                       thumbSizeTimer;
 
     // left side bar
-    AlbumFolderViewSideBarWidget *albumFolderSideBar;
-    TagViewSideBarWidget         *tagViewSideBar;
-    DateFolderViewSideBarWidget  *dateViewSideBar;
-    TimelineSideBarWidget        *timelineSideBar;
-    SearchSideBarWidget          *searchSideBar;
-    FuzzySearchSideBarWidget     *fuzzySearchSideBar;
+    AlbumFolderViewSideBarWidget* albumFolderSideBar;
+    TagViewSideBarWidget*         tagViewSideBar;
+    DateFolderViewSideBarWidget*  dateViewSideBar;
+    TimelineSideBarWidget*        timelineSideBar;
+    SearchSideBarWidget*          searchSideBar;
+    FuzzySearchSideBarWidget*     fuzzySearchSideBar;
 #ifdef HAVE_MARBLEWIDGET
-    GPSSearchSideBarWidget       *gpsSearchSideBar;
+    GPSSearchSideBarWidget*       gpsSearchSideBar;
 #endif
 
-    DigikamApp*               parent;
+    DigikamApp*                   parent;
 
-    DigikamImageView*         iconView;
-    AlbumManager*             albumManager;
-    AlbumHistory*             albumHistory;
-    AlbumWidgetStack*         albumWidgetStack;
+    DigikamImageView*             iconView;
+    AlbumManager*                 albumManager;
+    AlbumHistory*                 albumHistory;
+    AlbumWidgetStack*             albumWidgetStack;
 
-    AlbumModificationHelper*  albumModificationHelper;
-    TagModificationHelper*    tagModificationHelper;
-    SearchModificationHelper* searchModificationHelper;
+    AlbumModificationHelper*      albumModificationHelper;
+    TagModificationHelper*        tagModificationHelper;
+    SearchModificationHelper*     searchModificationHelper;
 
-    Sidebar*                  leftSideBar;
-    ImagePropertiesSideBarDB* rightSideBar;
+    Sidebar*                      leftSideBar;
+    ImagePropertiesSideBarDB*     rightSideBar;
 
-    TagFilterSideBarWidget *tagFilterWidget;
+    TagFilterSideBarWidget*       tagFilterWidget;
 
-    QString optionAlbumViewPrefix;
+    QString                       optionAlbumViewPrefix;
 
-    QList<SidebarWidget*> leftSideBarWidgets;
+    QList<SidebarWidget*>         leftSideBarWidgets;
 
-    DigikamModelCollection *modelCollection;
+    DigikamModelCollection*       modelCollection;
 
 };
 
@@ -412,9 +429,9 @@ void DigikamView::setupConnections()
     // -- Filter Bars Connections ---------------------------------
 
     connect(d->tagFilterWidget,
-            SIGNAL(tagFilterChanged(const QList<int>&, ImageFilterSettings::MatchingCondition, bool)),
+            SIGNAL(tagFilterChanged(const QList<int>&, const QList<int>&, ImageFilterSettings::MatchingCondition, bool)),
             d->iconView->imageFilterModel(),
-            SLOT(setTagFilter(const QList<int>&, ImageFilterSettings::MatchingCondition, bool)));
+            SLOT(setTagFilter(const QList<int>&, const QList<int>&, ImageFilterSettings::MatchingCondition, bool)));
 
     // -- Preview image widget Connections ------------------------
 
@@ -1590,12 +1607,15 @@ void DigikamView::slideShow(const ImageInfoList& infoList)
 
     if (!d->cancelSlideShow)
     {
-        SlideShow *slide = new SlideShow(settings);
+        SlideShow* slide = new SlideShow(settings);
         if (startWithCurrent)
         {
             slide->setCurrent(d->iconView->currentUrl());
         }
 
+        connect(slide, SIGNAL(signalRatingChanged(const KUrl&, int)),
+                this, SLOT(slotRatingChanged(const KUrl&, int)));
+
         slide->show();
     }
 }
@@ -1664,4 +1684,18 @@ void DigikamView::slotLeftSideBarActivate(SidebarWidget *widget)
     d->leftSideBar->setActiveTab(widget);
 }
 
+void DigikamView::slotRatingChanged(const KUrl& url, int rating)
+{
+    rating = qMin(RatingMax, qMax(RatingMin, rating));
+    ImageInfo info(url);
+    if (!info.isNull())
+    {
+        MetadataHub hub;
+        hub.load(info);
+        hub.setRating(rating);
+        hub.write(info, MetadataHub::PartialWrite);
+        hub.write(info.filePath(), MetadataHub::FullWriteIfChanged);
+    }
+}
+
 }  // namespace Digikam
