@@ -70,7 +70,9 @@ KIO::Job* copy(const KUrl::List& srcList, const QList<qlonglong> ids, const PAlb
 
     QStringList filenames;
     foreach(const KUrl& url, srcList)
+    {
         filenames << url.fileName();
+    }
     ScanController::instance()->hintAtMoveOrCopyOfItems(ids, dest, filenames);
 
     return KIO::copy(srcList, destUrl);
@@ -82,7 +84,9 @@ KIO::Job* move(const KUrl::List& srcList, const QList<qlonglong> ids, const PAlb
 
     QStringList filenames;
     foreach(const KUrl& url, srcList)
+    {
         filenames << url.fileName();
+    }
     ScanController::instance()->hintAtMoveOrCopyOfItems(ids, dest, filenames);
 
     return KIO::move(srcList, destUrl);
@@ -120,7 +124,7 @@ KIO::Job* move(const KUrl::List& srcList, const PAlbum* dest)
     return KIO::move(srcList, destUrl);
 }
 
-KIO::CopyJob* rename(const ImageInfo& info, const QString newName)
+KIO::CopyJob* rename(const ImageInfo& info, const QString& newName)
 {
     KUrl oldUrl = info.databaseUrl();
     KUrl newUrl = oldUrl;
