@@ -24,15 +24,14 @@
 
 #define RECT_EXTENSION 300
 
-#include "iconview.h"
 #include "iconview.moc"
 
-// C++ includes.
+// C++ includes
 
 #include <climits>
 #include <cstdlib>
 
-// Qt includes.
+// Qt includes
 
 #include <QCache>
 #include <QList>
@@ -47,16 +46,16 @@
 #include <QStyleOption>
 #include <QRubberBand>
 
-// KDE includes.
+// KDE includes
+
 
-#include <kdebug.h>
 #include <kcursor.h>
 #include <kiconloader.h>
 #include <kglobalsettings.h>
 
-// Local includes.
+// Local includes
 
-#include "ratingbox.h"
+#include "ratingwidget.h"
 #include "drubberband.h"
 #include "thumbbar.h"
 #include "iconitem.h"
@@ -79,7 +78,7 @@ public:
         anchorItem               = 0;
         clearing                 = false;
         spacing                  = 10;
-        ratingBox                = 0;
+        ratingWidget             = 0;
         ratingItem               = 0;
 
         rubber                   = 0;
@@ -120,28 +119,28 @@ public:
 
     QCache<QString, QPixmap>  thumbnailBorderCache;
 
-    DRubberBand              *rubber;
+    DRubberBand*              rubber;
 
     QPoint                    dragStartPos;
 
-    QTimer                   *rearrangeTimer;
-    QTimer                   *toolTipTimer;
+    QTimer*                   rearrangeTimer;
+    QTimer*                   toolTipTimer;
 
-    IconItem                 *toolTipItem;
-    IconItem                 *currItem;
-    IconItem                 *anchorItem;
-    IconItem                 *storedVisibleItem; // store position for slotRearrange
-    IconItem                 *highlightedItem;
-    IconItem                 *ratingItem;
+    IconItem*                 toolTipItem;
+    IconItem*                 currItem;
+    IconItem*                 anchorItem;
+    IconItem*                 storedVisibleItem; // store position for slotRearrange
+    IconItem*                 highlightedItem;
+    IconItem*                 ratingItem;
 
-    IconGroupItem            *firstGroup;
-    IconGroupItem            *lastGroup;
+    IconGroupItem*            firstGroup;
+    IconGroupItem*            lastGroup;
 
-    RatingBox                *ratingBox;
+    RatingWidget*             ratingWidget;
 
     struct ItemContainer
     {
-        ItemContainer(ItemContainer *p, ItemContainer *n, const QRect &r)
+        ItemContainer(ItemContainer *p, ItemContainer *n, const QRect& r)
             : prev(p), next(n), rect(r)
         {
             if (prev)
@@ -176,7 +175,9 @@ IconView::IconView(QWidget* parent, const char* name)
     d->rearrangeTimer = new QTimer(this);
     d->toolTipTimer   = new QTimer(this);
     d->rubber         = new DRubberBand(this);
-    d->ratingBox      = new RatingBox(viewport());
+    d->ratingWidget   = new RatingWidget(viewport());
+    d->ratingWidget->setTracking(false);
+    d->ratingWidget->hide();
 
     connect(d->rearrangeTimer, SIGNAL(timeout()),
             this, SLOT(slotRearrange()));
@@ -187,7 +188,7 @@ IconView::IconView(QWidget* parent, const char* name)
     connect(AlbumSettings::instance(), SIGNAL(setupChanged()),
             this, SLOT(slotIconViewFontChanged()));
 
-    connect(d->ratingBox, SIGNAL(signalRatingChanged(int)),
+    connect(d->ratingWidget, SIGNAL(signalRatingChanged(int)),
             this, SLOT(slotEditRatingFromItem(int)));
 
     slotIconViewFontChanged();
@@ -262,7 +263,9 @@ IconItem* IconView::findItem(const QPoint& pos)
             foreach(IconItem *item, c->items)
             {
                 if (item->rect().contains(pos))
+                {
                     return item;
+                }
             }
         }
     }
@@ -312,7 +315,7 @@ int IconView::countSelected() const
     {
         for (IconItem *it = group->firstItem(); it; it = it->nextItem())
             if (it->isSelected())
-                c++;
+                ++c;
     }
 
     return c;
@@ -323,7 +326,7 @@ int IconView::groupCount() const
     int c = 0;
     for (IconGroupItem* group = d->firstGroup; group; group = group->nextGroup())
     {
-        c++;
+        ++c;
     }
 
     return c;
@@ -342,7 +345,7 @@ void IconView::clear(bool update)
         d->ratingItem->setEditRating(false);
         d->ratingItem = 0;
         unsetCursor();
-        d->ratingBox->hide();
+        d->ratingWidget->hide();
     }
 
     deleteContainers();
@@ -384,12 +387,16 @@ void IconView::clearSelection()
 
     QSet<IconItem*> selItems = d->selectedItems;
     foreach(IconItem *item, selItems)
+    {
         item->setSelected(false, false);
+    }
 
     d->selectedItems.clear();
 
     if (!wasBlocked)
+    {
         blockSignals(false);
+    }
 
     emit signalSelectionChanged();
 }
@@ -399,7 +406,9 @@ void IconView::selectAll()
     bool wasBlocked = signalsBlocked();
 
     if (!wasBlocked)
+    {
         blockSignals(true);
+    }
 
     for (IconItem* item = firstItem(); item; item = item->nextItem())
     {
@@ -410,7 +419,9 @@ void IconView::selectAll()
     }
 
     if (!wasBlocked)
+    {
         blockSignals(false);
+    }
 
     emit signalSelectionChanged();
 }
@@ -420,7 +431,9 @@ void IconView::invertSelection()
     bool wasBlocked = signalsBlocked();
 
     if (!wasBlocked)
+    {
         blockSignals(true);
+    }
 
     for (IconItem* item = firstItem(); item; item = item->nextItem())
     {
@@ -435,7 +448,9 @@ void IconView::invertSelection()
     }
 
     if (!wasBlocked)
+    {
         blockSignals(false);
+    }
 
     emit signalSelectionChanged();
 }
@@ -443,7 +458,9 @@ void IconView::invertSelection()
 void IconView::selectItem(IconItem* item, bool select)
 {
     if (!item)
+    {
         return;
+    }
 
     if (select)
     {
@@ -465,7 +482,9 @@ void IconView::setStoredVisibleItem(IconItem *item)
 void IconView::insertGroup(IconGroupItem* group)
 {
     if (!group)
+    {
         return;
+    }
 
     if (!d->firstGroup)
     {
@@ -489,7 +508,9 @@ void IconView::insertGroup(IconGroupItem* group)
 void IconView::takeGroup(IconGroupItem* group)
 {
     if (!group)
+    {
         return;
+    }
 
     // this is only to find an alternative visible item if all visible items
     // are removed
@@ -500,18 +521,26 @@ void IconView::takeGroup(IconGroupItem* group)
     {
         d->firstGroup = d->firstGroup->m_next;
         if (d->firstGroup)
+        {
             d->firstGroup->m_prev = 0;
+        }
         else
+        {
             d->firstGroup = d->lastGroup = 0;
+        }
         alternativeVisibleGroup = d->firstGroup;
     }
     else if (group == d->lastGroup)
     {
         d->lastGroup = d->lastGroup->m_prev;
-        if ( d->lastGroup )
+        if (d->lastGroup)
+        {
             d->lastGroup->m_next = 0;
+        }
         else
+        {
             d->firstGroup = d->lastGroup = 0;
+        }
         alternativeVisibleGroup = d->lastGroup->m_prev;
     }
     else
@@ -519,15 +548,23 @@ void IconView::takeGroup(IconGroupItem* group)
         IconGroupItem *i = group;
         if (i)
         {
-            if (i->m_prev )
+            if (i->m_prev)
+            {
                 i->m_prev->m_next = i->m_next;
-            if ( i->m_next )
+            }
+            if (i->m_next)
+            {
                 i->m_next->m_prev = i->m_prev;
+            }
 
             if (i->m_prev)
+            {
                 alternativeVisibleGroup = i->m_prev;
+            }
             else
+            {
                 alternativeVisibleGroup = i->m_next;
+            }
         }
     }
 
@@ -546,7 +583,9 @@ void IconView::takeGroup(IconGroupItem* group)
 void IconView::insertItem(IconItem* item)
 {
     if (!item)
+    {
         return;
+    }
 
     d->storedVisibleItem = findFirstVisibleItem();
     startRearrangeTimer();
@@ -555,7 +594,9 @@ void IconView::insertItem(IconItem* item)
 void IconView::takeItem(IconItem* item)
 {
     if (!item)
+    {
         return;
+    }
 
     // First remove item from any containers holding it
     IconViewPriv::ItemContainer *tmp = d->firstContainer;
@@ -579,14 +620,16 @@ void IconView::takeItem(IconItem* item)
     }
 
     if (d->highlightedItem == item)
+    {
         d->highlightedItem = 0;
+    }
 
     if (d->ratingItem == item)
     {
         d->ratingItem->setEditRating(false);
         d->ratingItem = 0;
         unsetCursor();
-        d->ratingBox->hide();
+        d->ratingWidget->hide();
     }
 
     // if it is current item, change the current item
@@ -594,8 +637,10 @@ void IconView::takeItem(IconItem* item)
     {
         d->currItem = item->nextItem();
         if (!d->currItem)
+        {
             d->currItem = item->prevItem();
         // defer calling d->currItem->setSelected (and emitting the signals) to slotRearrange
+        }
     }
 
     d->anchorItem = d->currItem;
@@ -604,7 +649,9 @@ void IconView::takeItem(IconItem* item)
     {
         d->storedVisibleItem = findFirstVisibleItem();
         if (d->storedVisibleItem == item)
+        {
             d->storedVisibleItem = d->currItem;
+        }
         startRearrangeTimer();
     }
 }
@@ -621,9 +668,13 @@ void IconView::setDelayedRearrangement(bool delayed)
     // but not from the same event queue thread stack location, it may be desirable to delay
     // the rearrangeTimer a bit
     if (delayed)
+    {
         d->rearrangeTimerInterval = 50;
+    }
     else
+    {
         d->rearrangeTimerInterval = 0;
+    }
 }
 
 void IconView::startRearrangeTimer()
@@ -653,32 +704,40 @@ void IconView::sort()
     IconGroupItem *group = d->firstGroup;
     int i = 0;
 
-    for ( ; group; group = group->m_next )
-        groups[ i++ ].group = group;
+    for (; group; group = group->m_next)
+    {
+        groups[i++].group = group;
+    }
 
     qsort( groups, gcount, sizeof( IconViewPriv::SortableItem ), cmpItems );
 
     IconGroupItem *prev = 0;
     group = 0;
 
-    for ( i = 0; i < (int)gcount; ++i )
+    for (i = 0; i < (int) gcount; ++i)
     {
-        group = groups[ i ].group;
-        if ( group )
+        group = groups[i].group;
+        if (group)
         {
             group->m_prev = prev;
 
-            if ( group->m_prev )
+            if (group->m_prev)
+            {
                 group->m_prev->m_next = group;
+            }
 
             group->m_next = 0;
         }
 
-        if ( i == 0 )
+        if (i == 0)
+        {
             d->firstGroup = group;
+        }
 
-        if ( i == (int)gcount - 1 )
+        if (i == (int) gcount - 1)
+        {
             d->lastGroup = group;
+        }
         prev = group;
     }
 
@@ -698,7 +757,7 @@ void IconView::slotRearrange()
         d->ratingItem->setEditRating(false);
         d->ratingItem = 0;
         unsetCursor();
-        d->ratingBox->hide();
+        d->ratingWidget->hide();
     }
 
     // hide tooltip
@@ -714,7 +773,9 @@ void IconView::slotRearrange()
     {
         // set the currItem to first item
         if (d->firstGroup)
+        {
             d->currItem = d->firstGroup->firstItem();
+        }
     }
     d->anchorItem = d->currItem;
 
@@ -771,7 +832,7 @@ bool IconView::arrangeItems()
         {
             changed = item->move(x, y) || changed;
             x       += itemW + d->spacing;
-            col++;
+            ++col;
 
             if (col >= numItemsPerRow)
             {
@@ -989,7 +1050,7 @@ void IconView::focusOutEvent(QFocusEvent* e)
         d->ratingItem->setEditRating(false);
         d->ratingItem = 0;
         unsetCursor();
-        d->ratingBox->hide();
+        d->ratingWidget->hide();
     }
 
     // hide tooltip
@@ -1185,7 +1246,7 @@ void IconView::contentsMouseMoveEvent(QMouseEvent* e)
         if (item && KGlobalSettings::changeCursorOverIcon() && item->clickToOpenRect().contains(e->pos()))
         {
             setCursor(Qt::PointingHandCursor);
-            d->ratingBox->hide();
+            d->ratingWidget->hide();
             if (d->ratingItem)
                 d->ratingItem->setEditRating(false);
             d->ratingItem = 0;
@@ -1199,15 +1260,15 @@ void IconView::contentsMouseMoveEvent(QMouseEvent* e)
 
             QRect rect = item->clickToRateRect();
             rect.moveTopLeft(contentsToViewport(rect.topLeft()));
-            d->ratingBox->setFixedSize(rect.width()+1, rect.height()+1);
-            d->ratingBox->move(rect.topLeft().x(), rect.topLeft().y());
-            d->ratingBox->setRating(item->rating());
-            d->ratingBox->show();
+            d->ratingWidget->setFixedSize(rect.width()+1, rect.height()+1);
+            d->ratingWidget->move(rect.topLeft().x(), rect.topLeft().y());
+            d->ratingWidget->setRating(item->rating());
+            d->ratingWidget->show();
         }
         else
         {
             unsetCursor();
-            d->ratingBox->hide();
+            d->ratingWidget->hide();
             if (d->ratingItem)
                 d->ratingItem->setEditRating(false);
             d->ratingItem = 0;
@@ -1359,7 +1420,7 @@ void IconView::contentsWheelEvent(QWheelEvent* e)
         d->ratingItem->setEditRating(false);
         d->ratingItem = 0;
         unsetCursor();
-        d->ratingBox->hide();
+        d->ratingWidget->hide();
     }
 
     d->toolTipItem = 0;
@@ -1404,13 +1465,37 @@ void IconView::keyPressEvent(QKeyEvent* e)
     {
         case Qt::Key_Home:
         {
-            IconItem* tmp = d->currItem;
-            d->currItem = firstItem();
-            d->anchorItem = d->currItem;
-            if (tmp)
-                tmp->repaint();
+            if (e->modifiers() & Qt::ShiftModifier)
+            {
+                IconItem* const tmp = d->currItem;
+                d->currItem = firstItem();
+                if (tmp)
+                    tmp->repaint();
+
+                // select items: anchor until before firstItem
+                // block signals while selecting all except the firstItem
+                blockSignals(true);
+                for (IconItem* i = d->anchorItem; i && ( i != firstItem() ); i = i->prevItem())
+                {
+                    i->setSelected(true, false);
+                }
+                blockSignals(false);
+
+                // select the firstItem with signals enabled to ensure updates
+                firstItem()->setSelected(true, false);
+            }
+            else
+            {
+                IconItem* const tmp = d->currItem;
+                d->currItem = firstItem();
+                d->anchorItem = d->currItem;
+                if (tmp)
+                    tmp->repaint();
+
+                // select only the first item
+                firstItem()->setSelected(true, true);
+            }
 
-            firstItem()->setSelected(true, true);
             ensureItemVisible(firstItem());
             handled = true;
             break;
@@ -1418,13 +1503,35 @@ void IconView::keyPressEvent(QKeyEvent* e)
 
         case Qt::Key_End:
         {
-            IconItem* tmp = d->currItem;
-            d->currItem   = lastItem();
-            d->anchorItem = d->currItem;
-            if (tmp)
-                tmp->repaint();
+            if (e->modifiers() & Qt::ShiftModifier)
+            {
+                IconItem* const tmp = d->currItem;
+                d->currItem = lastItem();
+                if (tmp)
+                    tmp->repaint();
 
-            lastItem()->setSelected(true, true);
+                // select items: current until lastItem
+                // block signals while selecting all except the lastItem
+                blockSignals(true);
+                for (IconItem* i = d->anchorItem; i && ( i != lastItem() ); i = i->nextItem())
+                {
+                    i->setSelected(true, false);
+                }
+                blockSignals(false);
+
+                // select the lastItem with signals enabled to ensure updates
+                lastItem()->setSelected(true, false);
+            }
+            else
+            {
+                IconItem* const tmp = d->currItem;
+                d->currItem = lastItem();
+                d->anchorItem = d->currItem;
+                if (tmp)
+                    tmp->repaint();
+
+                lastItem()->setSelected(true, true);
+            }
             ensureItemVisible(lastItem());
             handled = true;
             break;
@@ -1723,7 +1830,7 @@ void IconView::keyPressEvent(QKeyEvent* e)
             break;
         }
 
-        case Qt::Key_Next:
+        case Qt::Key_PageDown:
         {
             IconItem *item = 0;
 
@@ -1763,7 +1870,7 @@ void IconView::keyPressEvent(QKeyEvent* e)
             break;
         }
 
-        case Qt::Key_Prior:
+        case Qt::Key_PageUp:
         {
             IconItem *item = 0;
 
@@ -1863,7 +1970,7 @@ void IconView::keyPressEvent(QKeyEvent* e)
             d->ratingItem->setEditRating(false);
             d->ratingItem = 0;
             unsetCursor();
-            d->ratingBox->hide();
+            d->ratingWidget->hide();
         }
 
         emit signalSelectionChanged();
@@ -2068,12 +2175,12 @@ int IconView::cmpItems(const void *n1, const void *n2)
     return i1->group->compare( i2->group );
 }
 
-QPixmap IconView::thumbnailBorderPixmap(const QSize &pixSize)
+QPixmap IconView::thumbnailBorderPixmap(const QSize& pixSize)
 {
     const int radius         = 3;
     const QColor borderColor = QColor(0, 0, 0, 128);
 
-    QString cacheKey  = QString::number(pixSize.width()) + "-" + QString::number(pixSize.height());
+    QString cacheKey  = QString::number(pixSize.width()) + '-' + QString::number(pixSize.height());
     QPixmap *cachePix = d->thumbnailBorderCache.object(cacheKey);
 
     if (!cachePix)
