@@ -84,27 +84,28 @@ class ImageCategorizedViewPriv
 {
 public:
 
-    ImageCategorizedViewPriv()
+    ImageCategorizedViewPriv() :
+        model(0),
+        filterModel(0),
+        delegate(0),
+        showToolTip(false),
+        scrollToItemId(0),
+        delayedEnterTimer(0),
+        currentMouseEvent(0)
     {
-        model              = 0;
-        filterModel        = 0;
-        delegate           = 0;
-        scrollToItemId     = 0;
-        currentMouseEvent  = 0;
-        showToolTip        = false;
     }
 
-    ImageModel              *model;
-    ImageFilterModel        *filterModel;
+    ImageModel*       model;
+    ImageFilterModel* filterModel;
 
-    ImageDelegate           *delegate;
-    bool                     showToolTip;
+    ImageDelegate*    delegate;
+    bool              showToolTip;
 
-    qlonglong                scrollToItemId;
+    qlonglong         scrollToItemId;
 
-    QTimer                  *delayedEnterTimer;
+    QTimer*           delayedEnterTimer;
 
-    QMouseEvent             *currentMouseEvent;
+    QMouseEvent*      currentMouseEvent;
 };
 
 // -------------------------------------------------------------------------------
@@ -278,7 +279,9 @@ KUrl::List ImageCategorizedView::urls() const
     QList<ImageInfo> infos = imageInfos();
     KUrl::List urls;
     foreach (const ImageInfo& info, infos)
+    {
         urls << info.fileUrl();
+    }
     return urls;
 }
 
@@ -287,7 +290,9 @@ KUrl::List ImageCategorizedView::selectedUrls() const
     QList<ImageInfo> infos = selectedImageInfos();
     KUrl::List urls;
     foreach (const ImageInfo& info, infos)
+    {
         urls << info.fileUrl();
+    }
     return urls;
 }
 
@@ -301,7 +306,9 @@ ImageInfo ImageCategorizedView::nextInOrder(const ImageInfo &startingPoint, int
 {
     QModelIndex index = d->filterModel->indexForImageInfo(startingPoint);
     if (!index.isValid())
+    {
         return ImageInfo();
+    }
     return d->filterModel->imageInfo(d->filterModel->index(index.row() + nth, 0, QModelIndex()));
 }
 
