@@ -6,7 +6,7 @@
  * Date        : 2009-04-19
  * Description : Qt item view for images - the delegate
  *
- * Copyright (C) 2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,8 +24,6 @@
 #ifndef IMAGEDELEGATE_H
 #define IMAGEDELEGATE_H
 
-// Qt includes
-
 // Local includes
 
 #include "itemviewimagedelegate.h"
@@ -39,7 +37,6 @@ class ImageCategorizedView;
 class ImageDelegateOverlay;
 class ImageFilterModel;
 class ImageModel;
-class ImageDelegatePrivate;
 
 class ImageDelegate : public ItemViewImageDelegate
 {
@@ -47,21 +44,21 @@ class ImageDelegate : public ItemViewImageDelegate
 
 public:
 
-    ImageDelegate(ImageCategorizedView *parent);
+    ImageDelegate(ImageCategorizedView* parent);
     ~ImageDelegate();
 
-    virtual void paint(QPainter * painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    virtual void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
     virtual QPixmap pixmapForDrag(const QStyleOptionViewItem& option, const QList<QModelIndex>& indexes) const;
 
 
-    ImageCategoryDrawer *categoryDrawer() const;
+    ImageCategoryDrawer* categoryDrawer() const;
 
     virtual void setSpacing(int spacing);
     virtual void setDefaultViewOptions(const QStyleOptionViewItem& option);
     virtual bool acceptsToolTip(const QPoint& pos, const QRect& visualRect,
-                                const QModelIndex& index, QRect *tooltipRect = 0) const;
+                                const QModelIndex& index, QRect* tooltipRect = 0) const;
     virtual bool acceptsActivation(const QPoint& pos, const QRect& visualRect,
-                                   const QModelIndex& index, QRect *activationRect = 0) const;
+                                   const QModelIndex& index, QRect* activationRect = 0) const;
 
     QRect rect() const;
     QRect ratingRect() const;
@@ -69,6 +66,11 @@ public:
     QRect tagsRect() const;
     QRect actualPixmapRect(qlonglong imageid) const;
 
+public:
+
+    // Declared as public because of use in DigikamImageDelegate class.
+    class ImageDelegatePrivate;
+
 protected:
 
     /** Reimplement this to set contentWidth. This is the maximum width of all
@@ -81,13 +83,13 @@ protected:
     virtual void clearCaches();
 
     bool onActualPixmapRect(const QPoint& pos, const QRect& visualRect,
-                            const QModelIndex & index, QRect *actualRect) const;
+                            const QModelIndex& index, QRect* actualRect) const;
     void updateActualPixmapRect(qlonglong imageid, const QRect& rect);
 
     virtual void invalidatePaintingCache();
     virtual void updateSizeRectsAndPixmaps();
 
-    ImageDelegate(ImageDelegatePrivate &dd, ImageCategorizedView *parent);
+    ImageDelegate(ImageDelegate::ImageDelegatePrivate& dd, ImageCategorizedView* parent);
 
 private:
 
