@@ -7,9 +7,9 @@
  * Description : a combo box to list date.
  *               this widget come from libkdepim.
  *
- *  Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
- *  Copyright (c) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
- *  Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>
+ *  Copyright (C) 2002 Cornelius Schumacher <schumacher@kde.org>
+ *  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+ *  Copyright (C) 2004 Tobias Koenig <tokoe@kde.org>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,7 +29,6 @@
 
 // Qt includes
 
-#include <QComboBox>
 #include <QDateTime>
 #include <QMap>
 #include <QMouseEvent>
@@ -37,6 +36,7 @@
 
 // KDE includes
 
+#include "kcombobox.h"
 #include "kdatepickerpopup.h"
 
 namespace Digikam
@@ -59,7 +59,7 @@ namespace Digikam
   @author David Jarvie <software@astrojar.org.uk>
   @author Tobias Koenig <tokoe@kde.org>
 */
-class KDateEdit : public QComboBox
+class KDateEdit : public KComboBox
 {
   Q_OBJECT
 
