@@ -62,14 +62,15 @@ class AlbumFolderViewSideBarWidgetPriv
 {
 public:
     AlbumFolderViewSideBarWidgetPriv() :
+        albumModificationHelper(0),
         albumFolderView(0),
         searchTextBar(0)
     {
     }
 
-    AlbumModificationHelper *albumModificationHelper;
-    AlbumSelectionTreeView *albumFolderView;
-    SearchTextBar *searchTextBar;
+    AlbumModificationHelper* albumModificationHelper;
+    AlbumSelectionTreeView*  albumFolderView;
+    SearchTextBar*           searchTextBar;
 };
 
 AlbumFolderViewSideBarWidget::AlbumFolderViewSideBarWidget(QWidget *parent,
@@ -169,13 +170,15 @@ class TagViewSideBarWidgetPriv
 {
 public:
     TagViewSideBarWidgetPriv() :
-        tagModel(0)
+        tagModel(0),
+        tagSearchBar(0),
+        tagFolderView(0)
     {
     }
 
-    TagModel *tagModel;
-    SearchTextBar *tagSearchBar;
-    TagFolderView *tagFolderView;
+    TagModel*       tagModel;
+    SearchTextBar*  tagSearchBar;
+    TagFolderView*  tagFolderView;
 };
 
 TagViewSideBarWidget::TagViewSideBarWidget(QWidget *parent, TagModel *model) :
@@ -343,10 +346,6 @@ class TimelineSideBarWidgetPriv
 {
 public:
     TimelineSideBarWidgetPriv() :
-        configHistogramTimeUnitEntry("Histogram TimeUnit"),
-        configHistogramScaleEntry("Histogram Scale"),
-        configCursorPositionEntry("Cursor Position"),
-
         scaleBG(0),
         cursorCountLabel(0),
         scrollBar(0),
@@ -363,30 +362,34 @@ public:
         searchModificationHelper(0)
     {}
 
+    static const QString      configHistogramTimeUnitEntry;
+    static const QString      configHistogramScaleEntry;
+    static const QString      configCursorPositionEntry;
 
-    const QString       configHistogramTimeUnitEntry;
-    const QString       configHistogramScaleEntry;
-    const QString       configCursorPositionEntry;
+    QButtonGroup*             scaleBG;
+    QLabel*                   cursorCountLabel;
+    QScrollBar*               scrollBar;
+    QTimer*                   timer;
+    QToolButton*              resetButton;
+    QToolButton*              saveButton;
 
-    QButtonGroup*       scaleBG;
-    QLabel*             cursorCountLabel;
-    QScrollBar*         scrollBar;
-    QTimer*             timer;
-    QToolButton*        resetButton;
-    QToolButton*        saveButton;
+    KComboBox*                timeUnitCB;
+    KLineEdit*                nameEdit;
+    KSqueezedTextLabel*       cursorDateLabel;
 
-    KComboBox*          timeUnitCB;
-    KLineEdit*          nameEdit;
-    KSqueezedTextLabel* cursorDateLabel;
+    SearchTextBar*            searchDateBar;
+    EditableSearchTreeView*   timeLineFolderView;
+    TimeLineWidget*           timeLineWidget;
 
-    SearchTextBar*      searchDateBar;
-    EditableSearchTreeView* timeLineFolderView;
-    TimeLineWidget*     timeLineWidget;
-
-    SearchModel*        searchModel;
+    SearchModel*              searchModel;
 
     SearchModificationHelper *searchModificationHelper;
 };
+const QString TimelineSideBarWidgetPriv::configHistogramTimeUnitEntry("Histogram TimeUnit");
+const QString TimelineSideBarWidgetPriv::configHistogramScaleEntry("Histogram Scale");
+const QString TimelineSideBarWidgetPriv::configCursorPositionEntry("Cursor Position");
+
+// --------------------------------------------------------
 
 TimelineSideBarWidget::TimelineSideBarWidget(QWidget *parent, SearchModel *searchModel,
                                              SearchModificationHelper *searchModificationHelper) :
@@ -799,14 +802,15 @@ public:
     SearchSideBarWidgetPriv() :
         searchSearchBar(0),
         searchTreeView(0),
-        searchTabHeader(0)
+        searchTabHeader(0),
+        searchModel(0)
     {
     }
 
-    SearchTextBar*            searchSearchBar;
-    NormalSearchTreeView*     searchTreeView;
-    SearchTabHeader*          searchTabHeader;
-    SearchModel *searchModel;
+    SearchTextBar*        searchSearchBar;
+    NormalSearchTreeView* searchTreeView;
+    SearchTabHeader*      searchTabHeader;
+    SearchModel*          searchModel;
 };
 
 SearchSideBarWidget::SearchSideBarWidget(QWidget *parent,
@@ -911,13 +915,15 @@ class FuzzySearchSideBarWidgetPriv
 {
 public:
     FuzzySearchSideBarWidgetPriv() :
-        fuzzySearchView(0)
+        fuzzySearchView(0),
+        searchModel(0),
+        searchModificationHelper(0)
     {
     }
 
     FuzzySearchView*          fuzzySearchView;
-    SearchModel *searchModel;
-    SearchModificationHelper *searchModificationHelper;
+    SearchModel*              searchModel;
+    SearchModificationHelper* searchModificationHelper;
 };
 
 FuzzySearchSideBarWidget::FuzzySearchSideBarWidget(QWidget *parent,
@@ -1015,12 +1021,13 @@ class GPSSearchSideBarWidgetPriv
 {
 public:
     GPSSearchSideBarWidgetPriv() :
-        gpsSearchView(0)
+        gpsSearchView(0),
+        searchModel(0)
     {
     }
 
-    GPSSearchView*            gpsSearchView;
-    SearchModel *searchModel;
+    GPSSearchView* gpsSearchView;
+    SearchModel*   searchModel;
 };
 
 GPSSearchSideBarWidget::GPSSearchSideBarWidget(QWidget *parent, SearchModel *searchModel, SearchModificationHelper *searchModificationHelper) :
