@@ -24,26 +24,26 @@
 
 // Qt includes
 
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QSqlDatabase>
 #include <QString>
 #include <QStringList>
-#include <QDir>
-#include <QFileInfo>
-#include <QFile>
-#include <QSqlDatabase>
 
 // KDE includes
 
-#include <kcmdlineargs.h>
-#include <kapplication.h>
 #include <kaboutdata.h>
-#include <klocale.h>
+#include <kapplication.h>
+#include <kcmdlineargs.h>
 #include <kconfig.h>
+#include <kdebug.h>
+#include <kdeversion.h>
 #include <kglobal.h>
 #include <kimageio.h>
-#include <ktip.h>
-#include <kdeversion.h>
+#include <klocale.h>
 #include <kmessagebox.h>
-#include <kdebug.h>
+#include <ktip.h>
 
 // Libkexiv2 includes
 
@@ -52,16 +52,16 @@
 
 // Local includes
 
-#include "version.h"
-#include "daboutdata.h"
 #include "albummanager.h"
+#include "assistantdlg.h"
+#include "collectionlocation.h"
+#include "collectionmanager.h"
+#include "daboutdata.h"
 #include "databaseaccess.h"
 #include "databaseparameters.h"
-#include "scancontroller.h"
-#include "collectionmanager.h"
-#include "collectionlocation.h"
 #include "digikamapp.h"
-#include "assistantdlg.h"
+#include "scancontroller.h"
+#include "version.h"
 
 using namespace Digikam;
 
@@ -145,7 +145,9 @@ int main(int argc, char *argv[])
         AssistantDlg firstRun;
         app.setTopWidget(&firstRun);
         if (firstRun.exec() == QDialog::Rejected)
+        {
             return 1;
+        }
 
         // parameters are written to config
         firstAlbumPath = firstRun.firstAlbumPath();
@@ -171,16 +173,30 @@ int main(int argc, char *argv[])
     // create main window
     DigikamApp *digikam = new DigikamApp();
 
+    // Bug #247175:
+    // Add a connection to the destroyed() signal when the digiKam mainwindow has been
+    // closed. This should prevent digiKam from staying open in the background.
+    //
+    // Right now this is the easiest and cleanest fix for the described problem, but me might re-think the
+    // solution later on, just in case there are better ways to do it.
+    QObject::connect(digikam, SIGNAL(destroyed(QObject*)), &app, SLOT(quit()));
+
     app.setTopWidget(digikam);
     digikam->restoreSession();
     digikam->show();
 
     if (args && args->isSet("download-from"))
+    {
         digikam->downloadFrom(args->getOption("download-from"));
+    }
     else if (args && args->isSet("download-from-udi"))
+    {
         digikam->downloadFromUdi(args->getOption("download-from-udi"));
+    }
     else if (args && args->isSet("detect-camera"))
+    {
         digikam->autoDetect();
+    }
 
     QStringList tipsFiles;
     tipsFiles.append("digikam/tips");
@@ -190,7 +206,9 @@ int main(int argc, char *argv[])
     KGlobal::locale()->insertCatalog("libkdcraw");
 
     if (!app.isSessionRestored())
+    {
         KTipDialog::showMultiTip(0, tipsFiles, false);
+    }
 
     int ret = app.exec();
 
