@@ -8,7 +8,7 @@
  *               hierarchical view of digiKam tags.
  *
  * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Parts of the drawing code are inspired by qmenu.cpp and qitemdelegate.cpp.
  * Copyright follows:
@@ -27,10 +27,9 @@
  *
  * ============================================================ */
 
-#include "tagspopupmenu.h"
 #include "tagspopupmenu.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QPainter>
 #include <QPixmap>
@@ -41,21 +40,19 @@
 #include <QStyleOptionMenuItem>
 #include <QStyleOptionViewItem>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
-#include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ktoggleaction.h>
+#include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "album.h"
 #include "albumdb.h"
-#include "albumiconitem.h"
-#include "albumiconview.h"
 #include "albummanager.h"
 #include "albumthumbnailloader.h"
 #include "tageditdlg.h"
@@ -69,8 +66,8 @@ class TagToggleAction : public QWidgetAction
 {
 public:
 
-    TagToggleAction(const QString &text, QObject *parent);
-    TagToggleAction(const KIcon &icon, const QString &text, QObject *parent);
+    TagToggleAction(const QString& text, QObject *parent);
+    TagToggleAction(const KIcon& icon, const QString& text, QObject *parent);
     virtual QWidget *createWidget(QWidget * parent);
 
     void setSpecialChecked(bool checked);
@@ -296,19 +293,20 @@ QRect TagToggleMenuWidget::checkIndicatorSize(QStyleOption *option) const
 
 // ------------------------------------------------------------------------
 
-TagToggleAction::TagToggleAction(const QString &text, QObject *parent)
-               : QWidgetAction(parent)
+TagToggleAction::TagToggleAction(const QString& text, QObject *parent)
+               : QWidgetAction(parent),
+                 m_checked(false),
+                 m_checkBoxHidden(false)
 {
-    m_checked = false;
-    m_checkBoxHidden = false;
     setText(text);
     setCheckable(true);
 }
 
-TagToggleAction::TagToggleAction(const KIcon &icon, const QString &text, QObject *parent)
-               : QWidgetAction(parent)
+TagToggleAction::TagToggleAction(const KIcon& icon, const QString& text, QObject *parent)
+               : QWidgetAction(parent),
+                 m_checked(false),
+                 m_checkBoxHidden(false)
 {
-    m_checked = false;
     setIcon(icon);
     setText(text);
     setCheckable(true);
@@ -442,8 +440,7 @@ void TagsPopupMenu::slotAboutToShow()
 
         // also add the parents of the assigned tags
         QSet<int> parents;
-        for (QSet<int>::iterator it = d->assignedTags.begin();
-             it != d->assignedTags.end(); ++it)
+        for (QSet<int>::const_iterator it = d->assignedTags.constBegin(); it != d->assignedTags.constEnd(); ++it)
         {
             TAlbum* album = man->findTAlbum(*it);
             if (album)
@@ -497,7 +494,7 @@ void TagsPopupMenu::iterateAndBuildMenu(KMenu *menu, TAlbum *album)
     }
     qStableSort(sortedTags.begin(), sortedTags.end(), lessThanByTitle);
 
-    for (QList<Album*>::iterator it = sortedTags.begin(); it != sortedTags.end(); ++it)
+    for (QList<Album*>::const_iterator it = sortedTags.constBegin(); it != sortedTags.constEnd(); ++it)
     {
         TAlbum *a = (TAlbum*)*it;
 
@@ -560,6 +557,17 @@ KMenu* TagsPopupMenu::buildSubMenu(int tagid)
         action->setCheckBoxHidden(true);
         setAlbumIcon(action, album);
         popup->addAction(action);
+        popup->addSeparator();
+        d->toggleTagActions->addAction(action);
+    }
+    else    // DISPLAY
+    {
+        TagToggleAction *action = new TagToggleAction(i18n("Go to this Tag"), d->toggleTagActions);
+        action->setData(album->id());
+        action->setCheckBoxHidden(true);
+        setAlbumIcon(action, album);
+        popup->addAction(action);
+        popup->addSeparator();
         d->toggleTagActions->addAction(action);
     }
 
@@ -615,7 +623,7 @@ void TagsPopupMenu::slotAddTag(QAction *action)
     TAlbum* parent    = man->findTAlbum(tagID);
     if (!parent)
     {
-        kWarning(50003) << "Failed to find album with id " << tagID << endl;
+        kWarning() << "Failed to find album with id " << tagID;
         return;
     }
 
@@ -627,7 +635,7 @@ void TagsPopupMenu::slotAddTag(QAction *action)
     AlbumList tList = TagEditDlg::createTAlbum(parent, title, icon, errMap);
     TagEditDlg::showtagsListCreationError(kapp->activeWindow(), errMap);
 
-    for (AlbumList::iterator it = tList.begin(); it != tList.end(); ++it)
+    for (AlbumList::const_iterator it = tList.constBegin(); it != tList.constEnd(); ++it)
         emit signalTagActivated((*it)->id());
 }
 
