@@ -66,7 +66,7 @@ using namespace KDcrawIface;
 namespace DigikamTransformImagePlugin
 {
 
-class FreeRotationToolPriv
+class FreeRotationTool::FreeRotationToolPriv
 {
 public:
 
@@ -297,9 +297,6 @@ void FreeRotationTool::slotResetSettings()
 
 void FreeRotationTool::prepareEffect()
 {
-    kapp->setOverrideCursor(Qt::WaitCursor);
-    d->expanderBox->setEnabled(false);
-
     FreeRotationContainer settings = d->settingsView->settings();
     ImageIface* iface              = d->previewWidget->imageIface();
     DImg preview                   = iface->getPreviewImg();
@@ -311,8 +308,6 @@ void FreeRotationTool::prepareEffect()
 
 void FreeRotationTool::prepareFinal()
 {
-    d->expanderBox->setEnabled(false);
-
     ImageIface iface(0, 0);
     FreeRotationContainer settings = d->settingsView->settings();
     DImg* orgImage                 = iface.getOriginalImg();
@@ -354,12 +349,6 @@ void FreeRotationTool::putFinalData()
     iface.putOriginalImage(i18n("Free Rotation"), targetImage.bits(), targetImage.width(), targetImage.height());
 }
 
-void FreeRotationTool::renderingFinished()
-{
-    d->expanderBox->setEnabled(true);
-    kapp->restoreOverrideCursor();
-}
-
 QString FreeRotationTool::generateButtonLabel(const QPoint& p)
 {
     QString clickToSet     = i18n("Click to set");
@@ -422,8 +411,7 @@ QString FreeRotationTool::centerString(const QString& str, int maxLength)
 void FreeRotationTool::updatePoints()
 {
     // set labels
-    QString tmp;
-    tmp = generateButtonLabel(d->autoAdjustPoint1);
+    QString tmp = generateButtonLabel(d->autoAdjustPoint1);
     d->autoAdjustPoint1Btn->setText(tmp);
 
     tmp = generateButtonLabel(d->autoAdjustPoint2);
