@@ -12,7 +12,7 @@
  *
  * The forwarding code is copied from kdelibs' ForwardingSlavebase.
  * Copyright for the KDE file forwardingslavebase follows:
- * Copyright (c) 2004 Kevin Ottens <ervin@ipsquad.net>
+ * Copyright (C) 2004 Kevin Ottens <ervin@ipsquad.net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -250,7 +250,7 @@ void kio_digikamalbums::rename( const KUrl& src, const KUrl& dst, KIO::JobFlags
     QFileInfo info(dbUrlSrc.fileUrl().toLocalFile());
     bool renamingAlbum = info.isDir();
 
-    int srcAlbumID, dstAlbumID = -1;
+    int srcAlbumID = -1;
 
     if (renamingAlbum)
     {
@@ -270,7 +270,7 @@ void kio_digikamalbums::rename( const KUrl& src, const KUrl& dst, KIO::JobFlags
             return;
         }
 
-        dstAlbumID = access.db()->getAlbumForPath(dbUrlDst.albumRootId(), dbUrlDst.album(), false);
+        int dstAlbumID = access.db()->getAlbumForPath(dbUrlDst.albumRootId(), dbUrlDst.album(), false);
         if (dstAlbumID == -1)
         {
             error(KIO::ERR_UNKNOWN, i18n("Destination album %1 not found in database.", dst.directory()));
