@@ -61,7 +61,7 @@ class AlbumRootInfo
 {
 public:
 
-    AlbumRootInfo() : id(0), type(AlbumRoot::UndefinedType) {};
+    AlbumRootInfo() : id(0), type(AlbumRoot::UndefinedType), status(0) {};
 
     int             id;
     QString         label;
@@ -80,11 +80,11 @@ class AlbumInfo
 {
 public:
 
-    AlbumInfo() : id(0), iconAlbumRootId(0) {};
+    AlbumInfo() : id(0), albumRootId(0), iconAlbumRootId(0) {};
 
     typedef QList<AlbumInfo> List;
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
     int     id;
     int     albumRootId;
@@ -118,7 +118,7 @@ public:
 
     typedef QList<TagInfo> List;
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
     int     id;
     int     pid;
@@ -167,7 +167,7 @@ public:
 
     typedef QList<SearchInfo> List;
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
     int                  id;
     QString              name;
@@ -187,13 +187,13 @@ class AlbumShortInfo
 {
 public:
 
-    AlbumShortInfo() : id(0) {};
+    AlbumShortInfo() : id(0), albumRootId(0) {};
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
-    int         id;
-    QString     relativePath;
-    int         albumRootId;
+    int     id;
+    QString relativePath;
+    int     albumRootId;
 };
 
 class TagShortInfo
@@ -202,7 +202,7 @@ public:
 
     TagShortInfo() : id(0), pid(0) {};
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
     int     id;
     int     pid;
@@ -235,9 +235,9 @@ class ItemShortInfo
 {
 public:
 
-    ItemShortInfo() : id(0), albumID(0) {};
+    ItemShortInfo() : id(0), albumID(0), albumRootID(0) {};
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
     qlonglong id;
     QString   itemName;
@@ -252,10 +252,10 @@ public:
 
     ItemScanInfo()
         : id(0), albumID(0), status(DatabaseItem::UndefinedStatus),
-          category(DatabaseItem::UndefinedCategory)
+          category(DatabaseItem::UndefinedCategory), fileSize(0)
     {};
 
-    bool isNull() { return id == 0; }
+    bool isNull() const { return id == 0; }
 
     qlonglong              id;
     int                    albumID;
@@ -296,7 +296,7 @@ public:
 
     CommentInfo() : id(-1), imageId(-1), type(DatabaseComment::UndefinedType) {};
 
-    bool isNull() { return id == -1; }
+    bool isNull() const { return id == -1; }
 
     int                   id;
     qlonglong             imageId;
@@ -313,7 +313,7 @@ public:
 
     CopyrightInfo() : id(-1) {};
 
-    bool isNull() { return id == -1; }
+    bool isNull() const { return id == -1; }
 
     qlonglong id;
     QString   property;
