@@ -23,11 +23,9 @@
 
 #include "imageinfolist.h"
 
-// Local includes.
+// Local includes
 
 #include "imageinfo.h"
-#include "imagecomments_p.h"
-#include "imageposition_p.h"
 
 namespace Digikam
 {
