@@ -67,8 +67,10 @@ public:
 
 ImageQueryPostHooks::~ImageQueryPostHooks()
 {
-    foreach(ImageQueryPostHook *hook, m_postHooks)
+    foreach (ImageQueryPostHook *hook, m_postHooks)
+    {
         delete hook;
+    }
 }
 
 void ImageQueryPostHooks::addHook(ImageQueryPostHook* hook)
@@ -78,9 +80,13 @@ void ImageQueryPostHooks::addHook(ImageQueryPostHook* hook)
 
 bool ImageQueryPostHooks::checkPosition(double latitudeNumber, double longitudeNumber)
 {
-    foreach(ImageQueryPostHook *hook, m_postHooks)
+    foreach (ImageQueryPostHook *hook, m_postHooks)
+    {
         if (!hook->checkPosition(latitudeNumber, longitudeNumber))
+        {
             return false;
+        }
+    }
     return true;
 }
 
@@ -193,11 +199,16 @@ public:
     ImageQueryPostHooks    *hooks;
     SearchXml::Relation     relation;
 
-    inline QString prepareForLike(const QString &str)
+    inline QString prepareForLike(const QString &str) const
     {
         if (relation == SearchXml::Like || relation == SearchXml::NotLike)
+        {
             return '%' + str + '%';
-        else return str;
+        }
+        else
+        {
+            return str;
+        }
     }
 
     void addIntField(const QString& name)
@@ -356,7 +367,9 @@ public:
             else
                 sql += ") ";
             foreach (int v, values)
+            {
                 *boundValues << v;
+            }
             sql += " ) ";
         }
         else
@@ -373,8 +386,10 @@ public:
             sql += " (" + name + " IN (";
             AlbumDB::addBoundValuePlaceholders(sql, values.size());
             sql += ") ";
-            foreach (qlonglong v, values)
+            foreach (const qlonglong &v, values)
+            {
                 *boundValues << v;
+            }
             sql += " ) ";
         }
         else
@@ -402,7 +417,9 @@ public:
                 sql += "OR " + name + " IS NULL ";
 
             foreach (int v, values)
+            {
                 *boundValues << v;
+            }
             sql += " ) ";
         }
         else
@@ -442,12 +459,14 @@ public:
                 sql += name + " IN (";
                 AlbumDB::addBoundValuePlaceholders(sql, simpleValues.size());
                 foreach(const QString& value, simpleValues)
+                {
                     *boundValues << value;
+                }
                 sql += " ) ";
             }
             if (!wildcards.isEmpty())
             {
-                foreach(QString wildcard, wildcards)
+                foreach(QString wildcard, wildcards) // krazy:exclude=foreach
                 {
                     ImageQueryBuilder::addSqlOperator(sql, SearchXml::Or, firstCondition);
                     firstCondition = false;
@@ -631,7 +650,7 @@ public:
         }
     }
 
-    void addRectanglePositionSearch(double lon1, double lat1, double lon2, double lat2)
+    void addRectanglePositionSearch(double lon1, double lat1, double lon2, double lat2) const
     {
         // lon1 is always West of lon2. If the rectangle crosses 180 longitude, we have to treat a special case.
         if (lon1 <= lon2)
