@@ -44,6 +44,7 @@
 #include "imagecomments.h"
 #include "imagecopyright.h"
 #include "imageextendedproperties.h"
+#include "tagscache.h"
 
 namespace Digikam
 {
@@ -75,6 +76,11 @@ ImageScanner::ImageScanner(qlonglong imageid)
                                       shortInfo.album, albumRootPath, shortInfo.albumRootID).fileUrl().toLocalFile());
 }
 
+qlonglong ImageScanner::id() const
+{
+    return m_scanInfo.id;
+}
+
 void ImageScanner::setCategory(DatabaseItem::Category category)
 {
     // we don't have the necessary information in this class, but in CollectionScanner
@@ -144,7 +150,7 @@ bool lessThanForIdentity(const ItemScanInfo &a, const ItemScanInfo &b)
 bool ImageScanner::scanFromIdenticalFile()
 {
     // Get a list of other images that are identical. Source image shall not be included.
-    QList<ItemScanInfo> candidates = DatabaseAccess().db()->getIdenticalFiles((int)m_fileInfo.size(),
+    QList<ItemScanInfo> candidates = DatabaseAccess().db()->getIdenticalFiles(m_scanInfo.fileSize,
                                                             m_scanInfo.uniqueHash, m_scanInfo.id);
 
     if (!candidates.isEmpty())
@@ -183,6 +189,8 @@ void ImageScanner::prepareImage()
 {
     m_scanInfo.itemName         = m_fileInfo.fileName();
     m_scanInfo.modificationDate = m_fileInfo.lastModified();
+    // there is a limit here for file size <2TB
+    m_scanInfo.fileSize         = (int)m_fileInfo.size();
     // category is set by setCategory
 
     // the QByteArray is an ASCII hex string
@@ -193,25 +201,22 @@ void ImageScanner::addImage(int albumId)
 {
     prepareImage();
 
-    // there is a limit here for file size <2TB
-    int fileSize                = (int)m_fileInfo.size();
     m_scanInfo.albumID          = albumId;
     m_scanInfo.status           = DatabaseItem::Visible;
 
     kDebug() << "Adding new item" << m_fileInfo.filePath();
     m_scanInfo.id               = DatabaseAccess().db()->addItem(m_scanInfo.albumID, m_scanInfo.itemName,
                                                                  m_scanInfo.status, m_scanInfo.category,
-                                                                 m_scanInfo.modificationDate, fileSize,
+                                                                 m_scanInfo.modificationDate, m_scanInfo.fileSize,
                                                                  m_scanInfo.uniqueHash);
 }
 
 void ImageScanner::updateImage()
 {
     prepareImage();
-    int fileSize = (int)m_fileInfo.size();
 
     DatabaseAccess().db()->updateItem(m_scanInfo.id, m_scanInfo.category,
-                                      m_scanInfo.modificationDate, fileSize, m_scanInfo.uniqueHash);
+                                      m_scanInfo.modificationDate, m_scanInfo.fileSize, m_scanInfo.uniqueHash);
 }
 
 void ImageScanner::scanFile(ScanMode mode)
@@ -468,10 +473,9 @@ void ImageScanner::scanTags()
     QStringList keywords = var.toStringList();
     if (!keywords.isEmpty())
     {
-        DatabaseAccess access;
         // get tag ids, create if necessary
-        QList<int> tagIds = access.db()->getTagsFromTagPaths(keywords, true);
-        access.db()->addTagsToItems(QList<qlonglong>() << m_scanInfo.id, tagIds);
+        QList<int> tagIds = TagsCache::instance()->getOrCreateTags(keywords);
+        DatabaseAccess().db()->addTagsToItems(QList<qlonglong>() << m_scanInfo.id, tagIds);
     }
 }
 
@@ -553,6 +557,35 @@ void ImageScanner::scanAudioFile()
                                                DatabaseFields::Format);
 }
 
+void ImageScanner::copyProperties(qlonglong source, qlonglong dest)
+{
+    DatabaseAccess access;
+
+    DatabaseFields::ImageInformation imageInfoFields =
+            DatabaseFields::Rating |
+            DatabaseFields::CreationDate |
+            DatabaseFields::DigitizationDate;
+    QVariantList imageInfos = access.db()->getImageInformation(source, imageInfoFields);
+    if (!imageInfos.isEmpty())
+        access.db()->changeImageInformation(dest, imageInfos, imageInfoFields);
+
+    QVariantList positionData = access.db()->getImagePosition(source, DatabaseFields::ImagePositionsAll);
+    if (!positionData.isEmpty())
+        access.db()->addImagePosition(dest, positionData, DatabaseFields::ImagePositionsAll);
+
+    ImageComments commentsSource(access, source);
+    ImageComments commentsDest(access, dest);
+    commentsDest.replaceFrom(commentsSource);
+    commentsDest.apply(access);
+
+    ImageCopyright copyrightSource(source);
+    ImageCopyright copyrightDest(dest);
+    copyrightDest.replaceFrom(source);
+
+    access.db()->copyImageTags(source, dest);
+    access.db()->copyImageProperties(source, dest);
+}
+
 void ImageScanner::loadFromDisk()
 {
     m_hasMetadata = m_metadata.load(m_fileInfo.filePath());
@@ -564,16 +597,7 @@ void ImageScanner::loadFromDisk()
     // faster than loading twice from disk
     if (m_hasMetadata)
     {
-        m_img.setComments(m_metadata.getComments());
-
-#if KEXIV2_VERSION >= 0x010000
-        m_img.setExif(m_metadata.getExifEncoded());
-#else
-        m_img.setExif(m_metadata.getExif());
-#endif
-
-        m_img.setIptc(m_metadata.getIptc());
-        m_img.setXmp(m_metadata.getXmp());
+        m_img.setMetadata(m_metadata.data());
     }
 }
 
