@@ -119,20 +119,42 @@ LibsInfoDlg::LibsInfoDlg(QWidget *parent)
 
 #ifndef USE_EXT_LIBLENSFUN
 #   ifdef HAVE_GLIB2
-    list.insert(i18n("LibLensFun"),                  QString("%1.%2.%3-%4").arg(LF_VERSION_MAJOR)
-                                                                           .arg(LF_VERSION_MINOR)
-                                                                           .arg(LF_VERSION_MICRO)
-                                                                           .arg(LF_VERSION_BUGFIX));
+    list.insert(i18n("LibLensFun"),                  i18n("%1.%2.%3-%4 - internal library",
+                                                          LF_VERSION_MAJOR,
+                                                          LF_VERSION_MINOR,
+                                                          LF_VERSION_MICRO,
+                                                          LF_VERSION_BUGFIX));
 #   endif // HAVE_GLIB2
+#else
+    list.insert(i18n("LibLensFun"),                  i18n("external shared library"));
 #endif // USE_EXT_LIBLENSFUN
 
+#ifndef USE_EXT_LIBLQR
+#   ifdef HAVE_GLIB2
+    list.insert(i18n("LibLqr"),                      i18n("internal library"));
+#   endif // HAVE_GLIB2
+#else
+    list.insert(i18n("LibLqr"),                      i18n("external shared library"));
+#endif // USE_EXT_LIBLQR
+
     list.insert(i18n("LibPNG"),                      QString(PNG_LIBPNG_VER_STRING));
     list.insert(i18n("LibTIFF"),                     QString(TIFFLIB_VERSION_STR).replace('\n', ' '));
     list.insert(i18n("LibJPEG"),                     QString::number(JPEG_LIB_VERSION));
     list.insert(i18n("LibJasper"),                   QString(jas_getversion()));
     list.insert(i18n("LibCImg"),                     GreycstorationFilter::cimgVersionString());
     list.insert(i18n("LibLCMS"),                     QString::number(LCMS_VERSION));
-    list.insert(i18n("LibPGF"),                      libPGFVersion());
+
+#ifdef USE_EXT_LIBPGF
+    list.insert(i18n("LibPGF"),                      QString("%1 - %2").arg(libPGFVersion()).arg(i18n("external shared library")));
+#else
+    list.insert(i18n("LibPGF"),                      QString("%1 - %2").arg(libPGFVersion()).arg(i18n("internal library")));
+#endif // USE_EXT_LIBPGF
+
+#ifdef USE_EXT_LIBCLAPACK
+    list.insert(i18n("LibClapack"),                  i18n("external shared library"));
+#else
+    list.insert(i18n("LibClapack"),                  i18n("internal library"));
+#endif // USE_EXT_LIBCLAPACK
 
 #ifdef HAVE_MARBLEWIDGET
     list.insert(i18n("Marble widget"),               QString(MARBLE_VERSION_STRING));
