@@ -8,7 +8,7 @@
  *               standard libkdcraw parameters plus
  *               few customized for post processing.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,6 +29,7 @@
 // Qt includes
 
 #include <QList>
+#include <QMetaType>
 #include <QPolygon>
 
 // LibKDcraw includes
@@ -39,67 +40,43 @@
 
 #include "digikam_export.h"
 
+using namespace KDcrawIface;
+
 namespace Digikam
 {
 
-class DIGIKAM_EXPORT DRawDecoding : public KDcrawIface::RawDecodingSettings
+class DIGIKAM_EXPORT DRawDecoding : public RawDecodingSettings
 {
 
 public:
 
     /** Standard constructor with default settings 
      */
-    DRawDecoding()
-    {
-        resetPostProcessingSettings();
-    };
+    DRawDecoding();
+
+    /** Copy constructor. Creates a copy of a RawDecodingSettings object.
+     */
+    DRawDecoding(const RawDecodingSettings& prm);
 
     /** Standard destructor 
      */
-    virtual ~DRawDecoding(){};
+    virtual ~DRawDecoding();
 
     /** Method to use a settings to optimize time loading, for example to compute image histogram 
      */
-    void optimizeTimeLoading()
-    {
-        KDcrawIface::RawDecodingSettings::optimizeTimeLoading();
-        resetPostProcessingSettings();
-    };
+    void optimizeTimeLoading();
 
     /** Method to reset to default values all Raw processing settings.
      */
-    void resetPostProcessingSettings()
-    {
-        lightness    = 0.0;
-        contrast     = 1.0;
-        gamma        = 1.0;
-        saturation   = 1.0;
-        exposureComp = 0.0;
-        curveAdjust  = QPolygon();
-    };
+    void resetPostProcessingSettings();
 
     /** Method to check is a post-processing setting have been changed 
      */
-    bool postProcessingSettingsIsDirty()
-    {
-        return (lightness    != 0.0    ||
-                contrast     != 1.0    ||
-                gamma        != 1.0    ||
-                saturation   != 1.0    ||
-                exposureComp != 0.0    ||
-                !curveAdjust.isEmpty());
-    }
+    bool postProcessingSettingsIsDirty();
 
-    bool operator==(const DRawDecoding& other) const
-    {
-        return lightness     == other.lightness &&
-               contrast      == other.contrast &&
-               gamma         == other.gamma &&
-               saturation    == other.saturation &&
-               exposureComp  == other.exposureComp &&
-               curveAdjust   == other.curveAdjust &&
-               levelsAdjust  == other.levelsAdjust;
-    }
+    /** Equality operator.
+     */
+    bool operator==(const DRawDecoding& other) const;
 
 public:
 
@@ -126,12 +103,10 @@ public:
     /** Luminosity curve adjustments.
     */
     QPolygon curveAdjust;
-
-    /** Levels adjustments: 4 channels (L, R, G, B * 2 values).
-    */
-    QList<int> levelsAdjust;
 };
 
 }  // namespace Digikam
 
+Q_DECLARE_METATYPE(Digikam::DRawDecoding)
+
 #endif /* DRAW_DECODING_H */
