@@ -24,11 +24,11 @@
 #ifndef JPEGSETTINGS_H
 #define JPEGSETTINGS_H
 
-// KDE includes.
+// KDE includes
 
 #include <QWidget>
 
-// Local includes.
+// Local includes
 
 #include "digikam_export.h"
 
@@ -52,7 +52,9 @@ public:
     void setSubSamplingValue(int val);
     int  getSubSamplingValue();
 
-signals:
+    static int convertCompressionForLibJpeg(int value);
+
+Q_SIGNALS:
 
     void signalSettingsChanged();
 
