@@ -80,43 +80,43 @@ public:
         ICCPROFILE
     };
 
-    ImagePropertiesColorsTabPriv()
+    ImagePropertiesColorsTabPriv() :
+        blinkFlag(false),
+        regionBox(0),
+        regionBG(0),
+        minInterv(0),
+        maxInterv(0),
+        labelMeanValue(0),
+        labelPixelsValue(0),
+        labelStdDevValue(0),
+        labelCountValue(0),
+        labelMedianValue(0),
+        labelPercentileValue(0),
+        labelColorDepth(0),
+        labelAlphaChannel(0),
+        iccProfileWidget(0),
+        imageLoaderThread(0),
+        histogramBox(0)
     {
-        regionBox            = 0;
-        imageLoaderThread    = 0;
-        regionBG             = 0;
-        minInterv            = 0;
-        maxInterv            = 0;
-        labelMeanValue       = 0;
-        labelPixelsValue     = 0;
-        labelStdDevValue     = 0;
-        labelCountValue      = 0;
-        labelMedianValue     = 0;
-        labelPercentileValue = 0;
-        labelColorDepth      = 0;
-        labelAlphaChannel    = 0;
-        iccProfileWidget     = 0;
-        imageLoaderThread    = 0;
-        histogramBox         = 0;
     }
 
     bool                   blinkFlag;
 
-    QWidget               *regionBox;
+    QWidget*               regionBox;
 
-    QButtonGroup          *regionBG;
+    QButtonGroup*          regionBG;
 
-    QSpinBox              *minInterv;
-    QSpinBox              *maxInterv;
+    QSpinBox*              minInterv;
+    QSpinBox*              maxInterv;
 
-    DTextLabelValue       *labelMeanValue;
-    DTextLabelValue       *labelPixelsValue;
-    DTextLabelValue       *labelStdDevValue;
-    DTextLabelValue       *labelCountValue;
-    DTextLabelValue       *labelMedianValue;
-    DTextLabelValue       *labelPercentileValue;
-    DTextLabelValue       *labelColorDepth;
-    DTextLabelValue       *labelAlphaChannel;
+    DTextLabelValue*       labelMeanValue;
+    DTextLabelValue*       labelPixelsValue;
+    DTextLabelValue*       labelStdDevValue;
+    DTextLabelValue*       labelCountValue;
+    DTextLabelValue*       labelMedianValue;
+    DTextLabelValue*       labelPercentileValue;
+    DTextLabelValue*       labelColorDepth;
+    DTextLabelValue*       labelAlphaChannel;
 
     QString                currentFilePath;
     LoadingDescription     currentLoadingDescription;
@@ -128,10 +128,10 @@ public:
     DImg                   image;
     DImg                   imageSelection;
 
-    ICCProfileWidget      *iccProfileWidget;
-    SharedLoadSaveThread  *imageLoaderThread;
+    ICCProfileWidget*      iccProfileWidget;
+    SharedLoadSaveThread*  imageLoaderThread;
 
-    HistogramBox          *histogramBox;
+    HistogramBox*          histogramBox;
 };
 
 ImagePropertiesColorsTab::ImagePropertiesColorsTab(QWidget* parent)
