@@ -28,6 +28,7 @@
 #include <QVBoxLayout>
 #include <QStyle>
 #include <QLabel>
+#include <QtCore/QTimer>
 
 // KDE includes
 
@@ -690,15 +691,6 @@ MarkerClusterHolder::PixmapOperations WorldMapWidget::getClusterPixmap(const int
     bool havePixmap = me->d->thumbnailLoadThread->find(gpsInfo.url.path() , *clusterPixmap, maxOfWidths);
     if (havePixmap)
     {
-        // temporary workaround for BKO 217702: thumbnails for movies are too big
-        // The thumbnail returned for movies by ThumbnailLoadThread::find is too big.
-        // Once this is fixed, this check can be removed.
-        const QSize clusterPixmapSize = clusterPixmap->size();
-        if ((clusterPixmapSize.height()>maxOfWidths)||(clusterPixmapSize.width()>maxOfWidths))
-        {
-            *clusterPixmap = clusterPixmap->scaled(maxOfWidths, maxOfWidths, Qt::KeepAspectRatio);
-        }
-
         pixmapOperations|= MarkerClusterHolder::PixmapValid;
         return pixmapOperations;
     }
@@ -852,7 +844,7 @@ WorldMapThemeBtn::WorldMapThemeBtn(WorldMapWidget *map, QWidget *parent)
     d->mapThemeMenu->addSeparator();
 
     // settings for preview of the images in the clusters:
-    d->multiMarkerShowSingleImagesAction = d->mapThemeMenu->addAction(i18n("Previews single images"));
+    d->multiMarkerShowSingleImagesAction = d->mapThemeMenu->addAction(i18n("Preview single images"));
     d->multiMarkerShowSingleImagesAction->setCheckable(true);
     d->multiMarkerShowGroupImagesAction = d->mapThemeMenu->addAction(i18n("Preview grouped images"));
     d->multiMarkerShowGroupImagesAction->setCheckable(true);
