@@ -55,6 +55,6 @@ DIGIKAM_EXPORT bool jpegConvert(const QString& src, const QString& dest, const Q
 DIGIKAM_EXPORT bool isJpegImage(const QString& file);
 DIGIKAM_EXPORT bool copyFile(const QString& src, const QString& dst);
 
-}
+} // namespace Digikam
 
 #endif /* JPEGUTILS_H */
