@@ -1545,7 +1545,7 @@ jcopy_markers_setup (j_decompress_ptr srcinfo, JCOPY_OPTION option)
 
 GLOBAL(void)
 jcopy_markers_execute (j_decompress_ptr srcinfo, j_compress_ptr dstinfo,
-		       JCOPY_OPTION option)
+		       JCOPY_OPTION /*option*/)
 {
   jpeg_saved_marker_ptr marker;
 
@@ -1589,4 +1589,3 @@ jcopy_markers_execute (j_decompress_ptr srcinfo, j_compress_ptr dstinfo,
 }
 
 } // namespace Digikam
-
