@@ -6,7 +6,8 @@
  * Date        : 2009-03-23
  * Description : Qt Model for Albums
  *
- * Copyright (C) 2008-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2008-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,17 +25,22 @@
 #include "abstractalbummodel.moc"
 #include "abstractalbummodelpriv.h"
 
+// Qt includes
+
+#include <qpainter.h>
+
 // KDE includes
 
 #include <kdebug.h>
-#include <klocale.h>
 #include <kglobal.h>
+#include <kicon.h>
+#include <klocale.h>
 
 // Local includes
 
 #include "albummanager.h"
-#include "albumthumbnailloader.h"
 #include "albummodeldragdrophandler.h"
+#include "albumthumbnailloader.h"
 
 namespace Digikam
 {
@@ -341,9 +347,13 @@ Qt::ItemFlags AbstractAlbumModel::itemFlags(Album *) const
 {
     Qt::ItemFlags f = Qt::ItemIsSelectable|Qt::ItemIsEnabled;
     if (d->itemDrag)
+    {
         f |= Qt::ItemIsDragEnabled;
+    }
     if (d->itemDrop)
+    {
         f |= Qt::ItemIsDropEnabled;
+    }
     return f;
 }
 
@@ -355,7 +365,9 @@ bool AbstractAlbumModel::filterAlbum(Album *album) const
 void AbstractAlbumModel::slotAlbumAboutToBeAdded(Album *album, Album *parent, Album *prev)
 {
     if (!filterAlbum(album))
+    {
         return;
+    }
 
     if (album->isRoot() && d->rootBehavior == IgnoreRootAlbum)
     {
@@ -386,14 +398,18 @@ void AbstractAlbumModel::slotAlbumAdded(Album *album)
         d->addingAlbum = 0;
         endInsertRows();
         if (isRoot)
+        {
             emit rootAlbumAvailable();
+        }
     }
 }
 
 void AbstractAlbumModel::slotAlbumAboutToBeDeleted(Album *album)
 {
     if (!filterAlbum(album))
+    {
         return;
+    }
 
     if (album->isRoot() && d->rootBehavior == IgnoreRootAlbum)
     {
@@ -431,7 +447,9 @@ void AbstractAlbumModel::slotAlbumsCleared()
 void AbstractAlbumModel::slotAlbumIconChanged(Album* album)
 {
     if (!filterAlbum(album))
+    {
         return;
+    }
     QModelIndex index = indexForAlbum(album);
     emit dataChanged(index, index);
 }
@@ -482,7 +500,9 @@ void AbstractSpecificAlbumModel::slotGotThumbnailFromIcon(Album *album, const QP
     // see decorationRole() method of subclasses
 
     if (!filterAlbum(album))
+    {
         return;
+    }
 
     QModelIndex index = indexForAlbum(album);
     emit dataChanged(index, index);
@@ -502,7 +522,9 @@ void AbstractSpecificAlbumModel::slotReloadThumbnails()
 void AbstractSpecificAlbumModel::emitDataChangedForChildren(Album *album)
 {
     if (!album)
+    {
         return;
+    }
 
     for (Album *child = album->firstChild(); child; child = child->next())
     {
@@ -549,7 +571,9 @@ void AbstractCountingAlbumModel::excludeChildrenCount(const QModelIndex& index)
 {
     Album *album = albumForIndex(index);
     if (!album)
+    {
         return;
+    }
     m_includeChildrenAlbums.remove(album->id());
     updateCount(album);
 }
@@ -558,7 +582,9 @@ void AbstractCountingAlbumModel::includeChildrenCount(const QModelIndex& index)
 {
     Album *album = albumForIndex(index);
     if (!album)
+    {
         return;
+    }
     m_includeChildrenAlbums << album->id();
     updateCount(album);
 }
@@ -568,7 +594,9 @@ void AbstractCountingAlbumModel::setCountMap(const QMap<int, int>& idCountMap)
     m_countMap = idCountMap;
     QMap<int, int>::const_iterator it = m_countMap.constBegin();
     for (; it != m_countMap.constEnd(); ++it)
+    {
         updateCount(albumForId(it.key()));
+    }
 }
 
 void AbstractCountingAlbumModel::updateCount(Album *album)
@@ -663,7 +691,9 @@ QVariant AbstractCountingAlbumModel::albumData(Album *album, int role) const
     {
         QHash<int, int>::const_iterator it = m_countHashReady.constFind(album->id());
         if (it != m_countHashReady.constEnd())
+        {
             return QString("%1 (%2)").arg(albumName(album)).arg(it.value());
+        }
     }
     return AbstractSpecificAlbumModel::albumData(album, role);
 }
@@ -675,9 +705,7 @@ int AbstractCountingAlbumModel::albumCount(Album *album) const
     {
         return it.value();
     }
-
     return -1;
-
 }
 
 QString AbstractCountingAlbumModel::albumName(Album *album) const
@@ -722,7 +750,9 @@ AbstractCheckableAlbumModel::AbstractCheckableAlbumModel(Album::Type albumType,
 void AbstractCheckableAlbumModel::setCheckable(bool isCheckable)
 {
     if (isCheckable)
+    {
         m_extraFlags |= Qt::ItemIsUserCheckable;
+    }
     else
     {
         m_extraFlags &= ~Qt::ItemIsUserCheckable;
@@ -740,7 +770,9 @@ void AbstractCheckableAlbumModel::setRootCheckable(bool isCheckable)
     m_rootIsCheckable = isCheckable;
     Album *root = rootAlbum();
     if (!m_rootIsCheckable && root)
+    {
         setChecked(root, false);
+    }
 }
 
 bool AbstractCheckableAlbumModel::rootIsCheckable() const
@@ -751,9 +783,13 @@ bool AbstractCheckableAlbumModel::rootIsCheckable() const
 void AbstractCheckableAlbumModel::setTristate(bool isTristate)
 {
     if (isTristate)
+    {
         m_extraFlags |= Qt::ItemIsTristate;
+    }
     else
+    {
         m_extraFlags &= ~Qt::ItemIsTristate;
+    }
 }
 
 bool AbstractCheckableAlbumModel::isTristate() const
@@ -783,7 +819,10 @@ void AbstractCheckableAlbumModel::setCheckState(Album *album, Qt::CheckState sta
 
 void AbstractCheckableAlbumModel::toggleChecked(Album *album)
 {
-    setChecked(album, !isChecked(album));
+    if (checkState(album) != Qt::PartiallyChecked)
+    {
+        setChecked(album, !isChecked(album));
+    }
 }
 
 QList<Album *> AbstractCheckableAlbumModel::checkedAlbums() const
@@ -792,6 +831,12 @@ QList<Album *> AbstractCheckableAlbumModel::checkedAlbums() const
     return m_checkedAlbums.keys(Qt::Checked);
 }
 
+QList<Album *> AbstractCheckableAlbumModel::partiallyCheckedAlbums() const
+{
+    // return a list with all keys with value Qt::PartiallyChecked
+    return m_checkedAlbums.keys(Qt::PartiallyChecked);
+}
+
 void AbstractCheckableAlbumModel::resetAllCheckedAlbums()
 {
     QList<Album *> oldChecked = m_checkedAlbums.keys();
@@ -829,7 +874,8 @@ void AbstractCheckableAlbumModel::resetCheckedAlbums(QModelIndex parent)
 void AbstractCheckableAlbumModel::setDataForParents(QModelIndex &child, const QVariant& value, int role)
 {
     QModelIndex current = child;
-    while (current.isValid() && current != rootAlbumIndex()) {
+    while (current.isValid() && current != rootAlbumIndex())
+    {
         setData(current, value, role);
         current = parent(current);
     }
@@ -879,14 +925,34 @@ QVariant AbstractCheckableAlbumModel::albumData(Album *a, int role) const
 {
     if (role == Qt::CheckStateRole)
     {
-        if (m_extraFlags & Qt::ItemIsUserCheckable
+        if ((m_extraFlags & Qt::ItemIsUserCheckable)
             && (!a->isRoot() || m_rootIsCheckable))
         {
             // with Qt::Unchecked as default, albums not in the hash (initially all)
             // are simply regarded as unchecked
-            return m_checkedAlbums.value(a, Qt::Unchecked);
+            // Use Qt::PartiallyChecked only internally, dont't expose it to the TreeView
+            return (m_checkedAlbums.value(a, Qt::Unchecked) == Qt::Unchecked) ? Qt::Unchecked : Qt::Checked;
         }
     }
+    if (role == Qt::DecorationRole)
+    {
+        Qt::CheckState state = m_checkedAlbums.value(a, Qt::Unchecked);
+        if (isTristate() && state != Qt::Unchecked)
+        {
+            QPixmap icon = decorationRoleData(a).value<QPixmap>();
+            int overlay_size = qMax(16, qRound(qMax(icon.width(), icon.height()) / 3.0 * 2.0));
+            QPixmap pm(qMax(overlay_size, icon.width()),
+                       qMax(overlay_size, icon.height()));
+            pm.fill(Qt::transparent);
+            QPainter p(&pm);
+            p.drawPixmap(0, 0, icon);
+            p.drawPixmap(pm.width() - overlay_size,
+                         pm.height() - overlay_size,
+                         KIcon(state == Qt::PartiallyChecked ? "list-remove" : "list-add").pixmap(overlay_size, overlay_size));
+            return pm;
+        }
+    }
+
 
     return AbstractCountingAlbumModel::albumData(a, role);
 }
@@ -898,7 +964,9 @@ Qt::ItemFlags AbstractCheckableAlbumModel::flags(const QModelIndex& index) const
     {
         QModelIndex root = rootAlbumIndex();
         if (root.isValid() && index == root)
+        {
             extraFlags &= ~Qt::ItemIsUserCheckable;
+        }
     }
     return AbstractCountingAlbumModel::flags(index) | extraFlags;
 }
@@ -910,7 +978,9 @@ bool AbstractCheckableAlbumModel::setData(const QModelIndex& index, const QVaria
         Qt::CheckState state = (Qt::CheckState)value.toInt();
         Album *album = albumForIndex(index);
         if (!album)
+        {
             return false;
+        }
         //kDebug() << "Updating check state for album" << album->title() << "to" << value;
         m_checkedAlbums.insert(album, state);
         emit dataChanged(index, index);
@@ -918,14 +988,18 @@ bool AbstractCheckableAlbumModel::setData(const QModelIndex& index, const QVaria
         return true;
     }
     else
+    {
         return AbstractCountingAlbumModel::setData(index, value, role);
+    }
 }
 
 void AbstractCheckableAlbumModel::albumCleared(Album *album)
 {
     // preserve check state if album is only being moved
     if (!AlbumManager::instance()->isMovingAlbum(album))
+    {
         m_checkedAlbums.remove(album);
+    }
     AbstractCountingAlbumModel::albumCleared(album);
 }
 
