@@ -6,7 +6,8 @@
  * Date        : 2009-03-05
  * Description : Qt item model for database entries
  *
- * Copyright (C) 2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -211,7 +212,9 @@ QList<QModelIndex> ImageFilterModel::mapListToSource(const QList<QModelIndex>& i
 {
     QList<QModelIndex> sourceIndexes;
     foreach (const QModelIndex& index, indexes)
+    {
         sourceIndexes << mapToSource(index);
+    }
     return sourceIndexes;
 }
 
@@ -219,7 +222,9 @@ QList<QModelIndex> ImageFilterModel::mapListFromSource(const QList<QModelIndex>&
 {
     QList<QModelIndex> indexes;
     foreach (const QModelIndex& index, sourceIndexes)
+    {
         indexes << mapFromSource(index);
+    }
     return indexes;
 }
 
@@ -240,7 +245,9 @@ QList<ImageInfo> ImageFilterModel::imageInfos(const QList<QModelIndex>& indexes)
     Q_D(const ImageFilterModel);
     QList<ImageInfo> infos;
     foreach (const QModelIndex& index, indexes)
+    {
         infos << d->imageModel->imageInfo(mapToSource(index));
+    }
     return infos;
 }
 
@@ -249,7 +256,9 @@ QList<qlonglong> ImageFilterModel::imageIds(const QList<QModelIndex>& indexes) c
     Q_D(const ImageFilterModel);
     QList<qlonglong> ids;
     foreach (const QModelIndex& index, indexes)
+    {
         ids << d->imageModel->imageId(mapToSource(index));
+    }
     return ids;
 }
 
@@ -292,11 +301,11 @@ void ImageFilterModel::setDayFilter(const QList<QDateTime>& days)
     setImageFilterSettings(d->filter);
 }
 
-void ImageFilterModel::setTagFilter(const QList<int>& tags, ImageFilterSettings::MatchingCondition matchingCond,
+void ImageFilterModel::setTagFilter(const QList<int>& includedTags, const QList<int>& excludedTags, ImageFilterSettings::MatchingCondition matchingCond,
                                bool showUnTagged)
 {
     Q_D(ImageFilterModel);
-    d->filter.setTagFilter(tags, matchingCond, showUnTagged);
+    d->filter.setTagFilter(includedTags, excludedTags, matchingCond, showUnTagged);
     setImageFilterSettings(d->filter);
 }
 
@@ -612,7 +621,7 @@ void ImageFilterModelFilterer::process(ImageFilterModelTodoPackage package)
                 hasOneMatchForText = true;
         }
     }
-    
+
     if (checkVersion(package))
     {
         QMutexLocker lock(&d->mutex);
