@@ -6,7 +6,8 @@
  * Date        : 2009-03-05
  * Description : Qt item model for database entries
  *
- * Copyright (C) 2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -108,7 +109,7 @@ public Q_SLOTS:
      *  parameter at a time.
      */
     void setDayFilter(const QList<QDateTime>& days);
-    void setTagFilter(const QList<int>& tags, ImageFilterSettings::MatchingCondition matchingCond,
+    void setTagFilter(const QList<int>& includedTags, const QList<int>& excludedTags, ImageFilterSettings::MatchingCondition matchingCond,
                       bool showUnTagged=false);
     void setRatingFilter(int rating, ImageFilterSettings::RatingCondition ratingCond);
     void setMimeTypeFilter(int mimeTypeFilter);
