@@ -12,10 +12,10 @@
  * Adapted from fluxbox: Texture/TextureRender
  *
  * Texture.hh for Fluxbox Window Manager
- * Copyright (c) 2002-2003 Henrik Kinnunen <fluxbox@users.sourceforge.net>
+ * Copyright (C) 2002-2003 Henrik Kinnunen <fluxbox@users.sourceforge.net>
  *
  * from Image.hh for Blackbox - an X11 Window manager
- * Copyright (c) 1997 - 2000 Brad Hughes (bhughes@tcac.net)
+ * Copyright (C) 1997 - 2000 Brad Hughes (bhughes@tcac.net)
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -132,7 +132,7 @@ Texture::Texture(int w, int h, const QColor& from, const QColor& to,
         else if (gradient == Theme::DIAGONAL)
             doDgradient();
 
-        if (bevel & Theme::RAISED || bevel & Theme::SUNKEN)
+        if ((bevel & Theme::RAISED) || (bevel & Theme::SUNKEN))
             doBevel();
 
         buildImage();
