@@ -117,13 +117,7 @@ bool LoadingCache::putImage(const QString& cacheKey, DImg *img, const QString& f
 {
     bool successfulyInserted;
 
-    // use size of image as cache cost, take care for wrapped preview QImages
     int cost = img->numBytes();
-    QVariant attribute(img->attribute("previewQImage"));
-    if (attribute.isValid())
-    {
-        cost = attribute.value<QImage>().numBytes();
-    }
 
     successfulyInserted = d->imageCache.insert(cacheKey, img, cost);
 
@@ -183,16 +177,21 @@ void LoadingCache::setCacheSize(int megabytes)
 
 // --- Thumbnails ----
 
-const QImage *LoadingCache::retrieveThumbnail(const QString& cacheKey)
+const QImage *LoadingCache::retrieveThumbnail(const QString& cacheKey) const
 {
     return d->thumbnailImageCache[cacheKey];
 }
 
-const QPixmap *LoadingCache::retrieveThumbnailPixmap(const QString& cacheKey)
+const QPixmap *LoadingCache::retrieveThumbnailPixmap(const QString& cacheKey) const
 {
     return d->thumbnailPixmapCache[cacheKey];
 }
 
+bool LoadingCache::hasThumbnailPixmap(const QString& cacheKey) const
+{
+    return d->thumbnailPixmapCache.contains(cacheKey);
+}
+
 void LoadingCache::putThumbnail(const QString& cacheKey, const QImage& thumb, const QString& filePath)
 {
     int cost = thumb.numBytes();
