@@ -174,7 +174,8 @@ public:
     };
 
     SavingTask(LoadSaveThread* thread, DImg& img, const QString& filePath, const QString& format)
-        : LoadSaveTask(thread), m_filePath(filePath), m_format(format), m_img(img)
+        : LoadSaveTask(thread),
+          m_filePath(filePath), m_format(format), m_img(img), m_savingTaskStatus(SavingTaskStatusSaving)
         {};
 
     virtual void execute();
