@@ -156,51 +156,56 @@ class CIETongueWidget::CIETongueWidgetPriv
 {
 public:
 
-    CIETongueWidgetPriv()
+    CIETongueWidgetPriv() :
+        profileDataAvailable(true),
+        loadingImageMode(false),
+        loadingImageSucess(false),
+        needUpdatePixmap(false),
+        uncalibratedColor(false),
+        xBias(0),
+        yBias(0),
+        pxcols(0),
+        pxrows(0),
+        progressCount(0),
+        gridside(0),
+        progressTimer(0),
+        hMonitorProfile(0),
+        hXYZProfile(0),
+        hXFORM(0)
     {
-        profileDataAvailable = true;
-        loadingImageMode     = false;
-        loadingImageSucess   = false;
-        needUpdatePixmap     = false;
-        uncalibratedColor    = false;
-        hMonitorProfile      = 0;
-        hXYZProfile          = 0;
-        hXFORM               = 0;
-        Measurement.Patches  = 0;
-        Measurement.Allowed  = 0;
-        progressCount        = 0;
-        progressTimer        = 0;
-        progressPix          = SmallIcon("process-working", 22);
+        progressPix = SmallIcon("process-working", 22);
+        Measurement.Patches = 0;
+        Measurement.Allowed = 0;
     }
 
-    bool             profileDataAvailable;
-    bool             loadingImageMode;
-    bool             loadingImageSucess;
-    bool             needUpdatePixmap;
-    bool             uncalibratedColor;
+    bool            profileDataAvailable;
+    bool            loadingImageMode;
+    bool            loadingImageSucess;
+    bool            needUpdatePixmap;
+    bool            uncalibratedColor;
 
-    int              xBias;
-    int              yBias;
-    int              pxcols;
-    int              pxrows;
-    int              progressCount;           // Position of animation during loading/calculation.
+    int             xBias;
+    int             yBias;
+    int             pxcols;
+    int             pxrows;
+    int             progressCount;           // Position of animation during loading/calculation.
 
-    double           gridside;
+    double          gridside;
 
-    QPainter         painter;
+    QPainter        painter;
 
-    QTimer          *progressTimer;
+    QTimer*         progressTimer;
 
-    QPixmap          pixmap;
-    QPixmap          progressPix;
+    QPixmap         pixmap;
+    QPixmap         progressPix;
 
-    cmsHPROFILE      hMonitorProfile;
-    cmsHPROFILE      hXYZProfile;
-    cmsHTRANSFORM    hXFORM;
-    cmsCIExyYTRIPLE  Primaries;
-    cmsCIEXYZ        MediaWhite;
+    cmsHPROFILE     hMonitorProfile;
+    cmsHPROFILE     hXYZProfile;
+    cmsHTRANSFORM   hXFORM;
+    cmsCIExyYTRIPLE Primaries;
+    cmsCIEXYZ       MediaWhite;
 
-    MEASUREMENT      Measurement;
+    MEASUREMENT     Measurement;
 };
 
 CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMonitor)
@@ -212,9 +217,13 @@ CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMon
     cmsErrorAction(LCMS_ERROR_SHOW);
 
     if (hMonitor)
+    {
         d->hMonitorProfile = hMonitor;
+    }
     else
+    {
         d->hMonitorProfile = cmsCreate_sRGBProfile();
+    }
 
     d->hXYZProfile = cmsCreateXYZProfile();
     d->hXFORM      = cmsCreateTransform(d->hXYZProfile, TYPE_XYZ_16,
@@ -228,10 +237,14 @@ CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMon
 CIETongueWidget::~CIETongueWidget()
 {
     if (d->Measurement.Patches)
+    {
         free(d->Measurement.Patches);
+    }
 
     if (d->Measurement.Allowed)
+    {
         free(d->Measurement.Allowed);
+    }
 
     cmsDeleteTransform(d->hXFORM);
     cmsCloseProfile(d->hXYZProfile);
@@ -606,10 +619,14 @@ void CIETongueWidget::drawPatches()
             if (p->dwFlags & PATCH_HAS_XYZ_PROOF)
             {
                 if (p->XYZ.Y < 0.03)
+                {
                    continue;
+                }
 
                 if (p->XYZProof.Y < 0.03)
+                {
                    continue;
+                }
 
                 cmsCIExyY Pt;
                 cmsXYZ2xyY(&Pt, &p->XYZProof);
@@ -619,7 +636,9 @@ void CIETongueWidget::drawPatches()
                 mapPoint(icx2, icy2, &Pt);
 
                 if (icx2 < 5 || icy2 < 5 || icx1 < 5 || icy1 < 5)
+                {
                     continue;
+                }
 
                 d->painter.setPen(qRgb(255, 255, 0));
                 biasedLine(icx1, icy1, icx2, icy2);
@@ -754,13 +773,19 @@ void CIETongueWidget::updatePixmap()
     drawTongueGrid();
 
     if (d->MediaWhite.Y > 0.0)
+    {
         drawWhitePoint();
+    }
 
     if (d->Primaries.Red.Y != 0.0)
+    {
         drawColorantTriangle();
+    }
 
     if (d->Measurement.Patches && d->Measurement.Allowed)
+    {
         drawPatches();
+    }
 
     d->painter.end();
 }
@@ -794,7 +819,10 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
         QPixmap anim(d->progressPix.copy(0, d->progressCount*22, 22, 22));
         d->progressCount++;
-        if (d->progressCount == 8) d->progressCount = 0;
+        if (d->progressCount == 8)
+        {
+            d->progressCount = 0;
+        }
 
         // ... and we render busy text.
 
@@ -841,7 +869,9 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
     // Create CIE tongue if needed
     if (d->needUpdatePixmap)
+    {
         updatePixmap();
+    }
 
     // draw prerendered tongue
     p.drawPixmap(0, 0, d->pixmap);
