@@ -8,7 +8,7 @@
  *               editor with no support of digiKam database.
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,7 +46,7 @@
 
 using namespace Digikam;
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
     KAboutData aboutData("showfoto", "digikam",
                          ki18n("showFoto"),
@@ -65,21 +65,19 @@ int main(int argc, char *argv[])
     options.add("+[file(s) or folder(s)]", ki18n("File(s) or folder(s) to open"));
     KCmdLineArgs::addCmdLineOptions( options );
 
-#if KEXIV2_VERSION >= 0x000300
     KExiv2Iface::KExiv2::initializeExiv2();
-#endif
 
     KApplication app;
 
     KUrl::List urlList;
-    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
     for(int i = 0; i < args->count(); ++i)
     {
         urlList.append(args->url(i));
     }
     args->clear();
 
-    ShowFoto::ShowFoto *w = new ShowFoto::ShowFoto(urlList);
+    ShowFoto::ShowFoto* w = new ShowFoto::ShowFoto(urlList);
     app.setTopWidget(w);
     w->show();
 
@@ -88,9 +86,7 @@ int main(int argc, char *argv[])
 
     int ret = app.exec();
 
-#if KEXIV2_VERSION >= 0x000300
     KExiv2Iface::KExiv2::cleanupExiv2();
-#endif
 
     return ret;
 }
