@@ -6,7 +6,7 @@
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -48,27 +48,11 @@ using namespace Digikam;
 namespace ShowFoto
 {
 
-class SetupToolTipPriv
+class SetupToolTip::SetupToolTipPriv
 {
 public:
 
     SetupToolTipPriv() :
-        configGroupName("ImageViewer Settings"),
-        configShowToolTipsEntry("Show ToolTips"),
-        configToolTipsFontEntry("ToolTips Font"),
-        configToolTipsShowFileNameEntry("ToolTips Show File Name"),
-        configToolTipsShowFileDateEntry("ToolTips Show File Date"),
-        configToolTipsShowFileSizeEntry("ToolTips Show File Size"),
-        configToolTipsShowImageTypeEntry("ToolTips Show Image Type"),
-        configToolTipsShowImageDimEntry("ToolTips Show Image Dim"),
-        configToolTipsShowPhotoMakeEntry("ToolTips Show Photo Make"),
-        configToolTipsShowPhotoDateEntry("ToolTips Show Photo Date"),
-        configToolTipsShowPhotoFocalEntry("ToolTips Show Photo Focal"),
-        configToolTipsShowPhotoExpoEntry("ToolTips Show Photo Expo"),
-        configToolTipsShowPhotoModeEntry("ToolTips Show Photo Mode"),
-        configToolTipsShowPhotoFlashEntry("ToolTips Show Photo Flash"),
-        configToolTipsShowPhotoWBEntry("ToolTips Show Photo WB"),
-
         showFileDateBox(0),
         showFileNameBox(0),
         showFileSizeBox(0),
@@ -87,50 +71,67 @@ public:
         fontSelect(0)
         {}
 
-    const QString configGroupName;
-    const QString configShowToolTipsEntry;
-    const QString configToolTipsFontEntry;
-    const QString configToolTipsShowFileNameEntry;
-    const QString configToolTipsShowFileDateEntry;
-    const QString configToolTipsShowFileSizeEntry;
-    const QString configToolTipsShowImageTypeEntry;
-    const QString configToolTipsShowImageDimEntry;
-    const QString configToolTipsShowPhotoMakeEntry;
-    const QString configToolTipsShowPhotoDateEntry;
-    const QString configToolTipsShowPhotoFocalEntry;
-    const QString configToolTipsShowPhotoExpoEntry;
-    const QString configToolTipsShowPhotoModeEntry;
-    const QString configToolTipsShowPhotoFlashEntry;
-    const QString configToolTipsShowPhotoWBEntry;
+    static const QString configGroupName;
+    static const QString configShowToolTipsEntry;
+    static const QString configToolTipsFontEntry;
+    static const QString configToolTipsShowFileNameEntry;
+    static const QString configToolTipsShowFileDateEntry;
+    static const QString configToolTipsShowFileSizeEntry;
+    static const QString configToolTipsShowImageTypeEntry;
+    static const QString configToolTipsShowImageDimEntry;
+    static const QString configToolTipsShowPhotoMakeEntry;
+    static const QString configToolTipsShowPhotoDateEntry;
+    static const QString configToolTipsShowPhotoFocalEntry;
+    static const QString configToolTipsShowPhotoExpoEntry;
+    static const QString configToolTipsShowPhotoModeEntry;
+    static const QString configToolTipsShowPhotoFlashEntry;
+    static const QString configToolTipsShowPhotoWBEntry;
 
-    QCheckBox*    showFileDateBox;
-    QCheckBox*    showFileNameBox;
-    QCheckBox*    showFileSizeBox;
-    QCheckBox*    showImageDimBox;
-    QCheckBox*    showImageTypeBox;
-    QCheckBox*    showPhotoDateBox;
-    QCheckBox*    showPhotoExpoBox;
-    QCheckBox*    showPhotoFlashBox;
-    QCheckBox*    showPhotoFocalBox;
-    QCheckBox*    showPhotoMakeBox;
-    QCheckBox*    showPhotoModeBox;
-    QCheckBox*    showPhotoWbBox;
-    QCheckBox*    showToolTipsBox;
+    QCheckBox*           showFileDateBox;
+    QCheckBox*           showFileNameBox;
+    QCheckBox*           showFileSizeBox;
+    QCheckBox*           showImageDimBox;
+    QCheckBox*           showImageTypeBox;
+    QCheckBox*           showPhotoDateBox;
+    QCheckBox*           showPhotoExpoBox;
+    QCheckBox*           showPhotoFlashBox;
+    QCheckBox*           showPhotoFocalBox;
+    QCheckBox*           showPhotoMakeBox;
+    QCheckBox*           showPhotoModeBox;
+    QCheckBox*           showPhotoWbBox;
+    QCheckBox*           showToolTipsBox;
 
-    QGroupBox*    fileSettingBox;
-    QGroupBox*    photoSettingBox;
+    QGroupBox*           fileSettingBox;
+    QGroupBox*           photoSettingBox;
 
-    DFontSelect*  fontSelect;
+    DFontSelect*         fontSelect;
 };
+const QString SetupToolTip::SetupToolTipPriv::configGroupName("ImageViewer Settings");
+const QString SetupToolTip::SetupToolTipPriv::configShowToolTipsEntry("Show ToolTips");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsFontEntry("ToolTips Font");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowFileNameEntry("ToolTips Show File Name");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowFileDateEntry("ToolTips Show File Date");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowFileSizeEntry("ToolTips Show File Size");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowImageTypeEntry("ToolTips Show Image Type");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowImageDimEntry("ToolTips Show Image Dim");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoMakeEntry("ToolTips Show Photo Make");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoDateEntry("ToolTips Show Photo Date");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoFocalEntry("ToolTips Show Photo Focal");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoExpoEntry("ToolTips Show Photo Expo");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoModeEntry("ToolTips Show Photo Mode");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoFlashEntry("ToolTips Show Photo Flash");
+const QString SetupToolTip::SetupToolTipPriv::configToolTipsShowPhotoWBEntry("ToolTips Show Photo WB");
+
+// --------------------------------------------------------
 
 SetupToolTip::SetupToolTip(QWidget* parent)
             : QScrollArea(parent), d(new SetupToolTipPriv)
 {
-    QWidget *panel = new QWidget(viewport());
+    QWidget* panel      = new QWidget(viewport());
     setWidget(panel);
     setWidgetResizable(true);
 
-    QVBoxLayout *layout = new QVBoxLayout(panel);
+    QVBoxLayout* layout = new QVBoxLayout(panel);
     d->showToolTipsBox  = new QCheckBox(i18n("Show Thumbbar items' toolti&ps"), panel);
     d->showToolTipsBox->setWhatsThis(i18n("Set this option to display the image information when "
                                           "the mouse hovers over a thumbbar item."));
@@ -141,7 +142,7 @@ SetupToolTip::SetupToolTip(QWidget* parent)
     // --------------------------------------------------------
 
     d->fileSettingBox     = new QGroupBox(i18n("File/Image Information"), panel);
-    QVBoxLayout *gLayout1 = new QVBoxLayout(d->fileSettingBox);
+    QVBoxLayout* gLayout1 = new QVBoxLayout(d->fileSettingBox);
 
     d->showFileNameBox = new QCheckBox(i18n("Show file name"), d->fileSettingBox);
     d->showFileNameBox->setWhatsThis( i18n("Set this option to display the image file name."));
@@ -169,7 +170,7 @@ SetupToolTip::SetupToolTip(QWidget* parent)
     // --------------------------------------------------------
 
     d->photoSettingBox    = new QGroupBox(i18n("Photograph Information"), panel);
-    QVBoxLayout *gLayout2 = new QVBoxLayout(d->photoSettingBox);
+    QVBoxLayout* gLayout2 = new QVBoxLayout(d->photoSettingBox);
 
     d->showPhotoMakeBox = new QCheckBox(i18n("Show camera make and model"), d->photoSettingBox);
     d->showPhotoMakeBox->setWhatsThis( i18n("Set this option to display the make and model of the "
