@@ -106,7 +106,7 @@ extern "C"
 #include "loadingcacheinterface.h"
 #include "savingcontextcontainer.h"
 #include "setup.h"
-#include "setupeditor.h"
+#include "setupmisc.h"
 #include "setupicc.h"
 #include "slideshow.h"
 #include "splashscreen.h"
@@ -121,7 +121,7 @@ extern "C"
 namespace ShowFoto
 {
 
-class ShowFotoPriv
+class ShowFoto::ShowFotoPriv
 {
 public:
 
@@ -361,7 +361,6 @@ void ShowFoto::show()
             config->sync();
         }
     }
-
 }
 
 void ShowFoto::setupConnections()
@@ -486,16 +485,15 @@ void ShowFoto::readSettings()
     QString defaultDir =group.readEntry("Last Opened Directory", QString());
     if (defaultDir.isNull())
     {
-        #if KDE_IS_VERSION(4,1,61)
+#if KDE_IS_VERSION(4,1,61)
         defaultDir = KGlobalSettings::picturesPath();
-        #else
+#else
         defaultDir = QDesktopServices::storageLocation(QDesktopServices::PicturesLocation);
-        #endif
+#endif
     }
     d->lastOpenedDirectory.setPath(defaultDir);
 
-    Digikam::ThemeEngine::instance()->setCurrentTheme(group.readEntry("Theme", i18nc("default theme name",
-                                                                                     "Default")));
+    Digikam::ThemeEngine::instance()->setCurrentTheme(group.readEntry("Theme", i18nc("default theme name", "Default")));
 }
 
 void ShowFoto::saveSettings()
@@ -784,9 +782,9 @@ void ShowFoto::openFolder(const KUrl& url)
     QDir::SortFlags flag;
     bool reverse = group.readEntry("ReverseSort", false);
 
-    switch(group.readEntry("SortOrder", (int)SetupEditor::SortByDate))
+    switch(group.readEntry("SortOrder", (int)SetupMisc::SortByDate))
     {
-        case SetupEditor::SortByName:
+        case SetupMisc::SortByName:
         {
             flag = QDir::Name;  // Ordering by file name.
             if (reverse)
@@ -795,7 +793,7 @@ void ShowFoto::openFolder(const KUrl& url)
             }
             break;
         }
-        case SetupEditor::SortByFileSize:
+        case SetupMisc::SortByFileSize:
         {
             flag = QDir::Size;  // Ordering by file size.
 
