@@ -6,7 +6,7 @@
  * Date        : 2009-09-14
  * Description : a rename dialog for the AdvancedRename utility
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,11 +45,12 @@
 #include "parser.h"
 #include "parsesettings.h"
 #include "advancedrenamemanager.h"
+#include "advancedrenameprocessdialog.h"
 
 namespace Digikam
 {
 
-class AdvancedRenameListItemPriv
+class AdvancedRenameListItem::AdvancedRenameListItemPriv
 {
 public:
 
@@ -137,15 +138,11 @@ bool AdvancedRenameListItem::isInvalid()
 
 // --------------------------------------------------------
 
-class AdvancedRenameDialogPriv
+class AdvancedRenameDialog::AdvancedRenameDialogPriv
 {
 public:
 
     AdvancedRenameDialogPriv() :
-        configGroupName("AdvancedRename Dialog"),
-        configLastUsedRenamePatternEntry("Last Used Rename Pattern"),
-        configDialogSizeEntry("Dialog Size"),
-
         singleFileMode(false),
         minSizeDialog(450),
         listView(0),
@@ -153,9 +150,9 @@ public:
         advancedRenameWidget(0)
     {}
 
-    const QString          configGroupName;
-    const QString          configLastUsedRenamePatternEntry;
-    const QString          configDialogSizeEntry;
+    static const QString   configGroupName;
+    static const QString   configLastUsedRenamePatternEntry;
+    static const QString   configDialogSizeEntry;
 
     QString                singleFileModeOldFilename;
 
@@ -167,6 +164,11 @@ public:
     AdvancedRenameWidget*  advancedRenameWidget;
     NewNamesList           newNamesList;
 };
+const QString AdvancedRenameDialog::AdvancedRenameDialogPriv::configGroupName("AdvancedRename Dialog");
+const QString AdvancedRenameDialog::AdvancedRenameDialogPriv::configLastUsedRenamePatternEntry("Last Used Rename Pattern");
+const QString AdvancedRenameDialog::AdvancedRenameDialogPriv::configDialogSizeEntry("Dialog Size");
+
+// --------------------------------------------------------
 
 AdvancedRenameDialog::AdvancedRenameDialog(QWidget* parent)
                     : KDialog(parent), d(new AdvancedRenameDialogPriv)
@@ -238,7 +240,9 @@ void AdvancedRenameDialog::slotReturnPressed()
 void AdvancedRenameDialog::slotParseStringChanged(const QString& parseString)
 {
     if (!d->advancedRenameManager)
+    {
         return;
+    }
 
     d->newNamesList.clear();
 
