@@ -6,7 +6,7 @@
  * Date        : 2009-09-03
  * Description : an input widget for the AdvancedRename utility
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -96,7 +96,7 @@ void AdvancedRenameLineEditProxy::mouseReleaseEvent(QMouseEvent* event)
 
 // --------------------------------------------------------
 
-class AdvancedRenameLineEditPriv
+class AdvancedRenameLineEdit::AdvancedRenameLineEditPriv
 {
 public:
 
@@ -175,7 +175,7 @@ void AdvancedRenameLineEdit::setParser(Parser* parser)
     }
 }
 
-Parser* AdvancedRenameLineEdit::parser()
+Parser* AdvancedRenameLineEdit::parser() const
 {
     return d->parser;
 }
@@ -268,22 +268,19 @@ void AdvancedRenameLineEdit::slotSetText(const QString& text)
 
 // --------------------------------------------------------
 
-class AdvancedRenameInputPriv
+class AdvancedRenameInput::AdvancedRenameInputPriv
 {
 public:
 
     AdvancedRenameInputPriv() :
-        configGroupName("AdvancedRename Input"),
-        configPatternHistoryListEntry("Pattern History List"),
-
         maxVisibleItems(10),
         maxHistoryItems(30),
         lineEdit(0),
         highlighter(0)
     {}
 
-    const QString           configGroupName;
-    const QString           configPatternHistoryListEntry;
+    static const QString    configGroupName;
+    static const QString    configPatternHistoryListEntry;
 
     const int               maxVisibleItems;
     const int               maxHistoryItems;
@@ -293,6 +290,8 @@ public:
     AdvancedRenameLineEdit* lineEdit;
     Highlighter*            highlighter;
 };
+const QString AdvancedRenameInput::AdvancedRenameInputPriv::configGroupName("AdvancedRename Input");
+const QString AdvancedRenameInput::AdvancedRenameInputPriv::configPatternHistoryListEntry("Pattern History List");
 
 // --------------------------------------------------------
 
@@ -397,9 +396,8 @@ void AdvancedRenameInput::enableHighlighter(bool enable)
         delete d->highlighter;
     }
 
-    d->highlighter = enable ?
-            new Highlighter(d->lineEdit, d->lineEdit->parser()) :
-            0;
+    d->highlighter = enable ? new Highlighter(d->lineEdit, d->lineEdit->parser())
+                            : 0;
 }
 
 void AdvancedRenameInput::changeEvent(QEvent* e)
