@@ -6,7 +6,7 @@
  * Date        : 2010-08-08
  * Description : a class that manages the files to be renamed
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,6 +25,7 @@
 
 // Qt includes
 
+#include <QList>
 #include <QMap>
 #include <QFileInfo>
 
@@ -42,7 +43,7 @@
 namespace Digikam
 {
 
-class ParseManagerPriv
+class AdvancedRenameManager::ParseManagerPriv
 {
 public:
 
@@ -57,6 +58,7 @@ public:
 
     QStringList                       files;
     QMap<QString, int>                fileIndexMap;
+    QMap<QString, int>                folderIndexMap;
     QMap<QString, int>                fileGroupIndexMap;
     QMap<QString, QDateTime>          fileDatesMap;
     QMap<QString, QString>            renamedFiles;
@@ -166,16 +168,18 @@ void AdvancedRenameManager::setParserType(ParserType type)
 Parser* AdvancedRenameManager::getParser()
 {
     if (!d->parser)
+    {
         return 0;
-
+    }
     return d->parser;
 }
 
 void AdvancedRenameManager::parseFiles()
 {
     if (!d->widget)
+    {
         return;
-
+    }
     parseFiles(d->widget->parseString());
 }
 
@@ -197,7 +201,9 @@ void AdvancedRenameManager::parseFiles(ParseSettings& _settings)
 void AdvancedRenameManager::parseFiles(const QString& parseString)
 {
     if (!d->parser)
+    {
         return;
+    }
 
     foreach (const QString& file, fileList())
     {
@@ -216,7 +222,9 @@ void AdvancedRenameManager::parseFiles(const QString& parseString)
 void AdvancedRenameManager::parseFiles(const QString& parseString, ParseSettings& _settings)
 {
     if (!d->parser)
+    {
         return;
+    }
 
     foreach (const QString& file, fileList())
     {
@@ -244,6 +252,7 @@ void AdvancedRenameManager::addFiles(const QList<ParseSettings>& files, SortType
 void AdvancedRenameManager::clearMappings()
 {
     d->fileIndexMap.clear();
+    d->folderIndexMap.clear();
     d->fileGroupIndexMap.clear();
     d->renamedFiles.clear();
     d->fileGroupIndexMap.clear();
@@ -322,6 +331,37 @@ bool AdvancedRenameManager::initialize()
         }
     }
 
+    // fill folder group index map
+    {
+        counter = 1;
+        QMap<QString, QList<QString> > dirMap;
+        foreach (const QString& file, fileList())
+        {
+            QFileInfo fi(file);
+            QString path = fi.absolutePath();
+            if (!path.isEmpty())
+            {
+                if (!dirMap.contains(path))
+                {
+                    dirMap[path] = QList<QString>();
+                }
+                dirMap[path].push_back(file);
+            }
+        }
+
+        foreach (const QString& dir, dirMap.keys())
+        {
+            int index = 0;
+            foreach (const QString& f, dirMap[dir])
+            {
+                if (!d->folderIndexMap.contains(f))
+                {
+                    d->folderIndexMap[f] = ++index;
+                }
+            }
+        }
+    }
+
     return true;
 }
 
@@ -344,6 +384,18 @@ int AdvancedRenameManager::indexOfFile(const QString& filename)
     return index;
 }
 
+int AdvancedRenameManager::indexOfFolder(const QString& filename)
+{
+    int index = -1;
+
+    if (d->folderIndexMap.contains(filename))
+    {
+        index = d->folderIndexMap.value(filename);
+    }
+
+    return index;
+}
+
 int AdvancedRenameManager::indexOfFileGroup(const QString& filename)
 {
     int index = -1;
