@@ -57,7 +57,7 @@ using namespace KDcrawIface;
 namespace Digikam
 {
 
-class AdvancedRenameWidgetPriv
+class AdvancedRenameWidget::AdvancedRenameWidgetPriv
 {
     typedef AdvancedRenameWidget::ControlWidgets CWMask;
     typedef AdvancedRenameWidget::LayoutStyle    LStyle;
@@ -65,10 +65,7 @@ class AdvancedRenameWidgetPriv
 public:
 
     AdvancedRenameWidgetPriv() :
-        configGroupName("AdvancedRename Widget"),
-        configExpandedStateEntry("Options are expanded"),
         configExpandedStateDefault(true),
-
         tooltipToggleButton(0),
         modifiersToolButton(0),
         optionsButton(0),
@@ -82,8 +79,9 @@ public:
         layoutStyle(AdvancedRenameWidget::LayoutNormal)
     {}
 
-    const QString        configGroupName;
-    const QString        configExpandedStateEntry;
+    static const QString configGroupName;
+    static const QString configExpandedStateEntry;
+
     bool                 configExpandedStateDefault;
 
     QToolButton*         tooltipToggleButton;
@@ -102,6 +100,10 @@ public:
     CWMask               controlWidgetsMask;
     LStyle               layoutStyle;
 };
+const QString AdvancedRenameWidget::AdvancedRenameWidgetPriv::configGroupName("AdvancedRename Widget");
+const QString AdvancedRenameWidget::AdvancedRenameWidgetPriv::configExpandedStateEntry("Options are expanded");
+
+// --------------------------------------------------------
 
 AdvancedRenameWidget::AdvancedRenameWidget(QWidget* parent)
                     : QWidget(parent), d(new AdvancedRenameWidgetPriv)
@@ -278,7 +280,7 @@ void AdvancedRenameWidget::registerParserControls()
    }
 }
 
-Parser* AdvancedRenameWidget::parser()
+Parser* AdvancedRenameWidget::parser() const
 {
     return d->parser;
 }
