@@ -92,30 +92,17 @@ Parser::Parser()
 
 Parser::~Parser()
 {
-    foreach (Option* option, d->options)
-    {
-        delete option;
-    }
+    qDeleteAll(d->options);
     d->options.clear();
 
-    foreach (Modifier* modifier, d->modifiers)
-    {
-        delete modifier;
-    }
+    qDeleteAll(d->modifiers);
     d->modifiers.clear();
 
     delete d;
 }
 
-//void Parser::init(const ParseSettings& settings)
-//{
-//    d->globalSettings = settings;
-////    d->counter  = 1;
-//}
-
 void Parser::reset()
 {
-//    init(ParseSettings());
     foreach (Option* option, d->options)
     {
         option->reset();
@@ -154,7 +141,10 @@ void Parser::registerOption(Option* option)
 
 void Parser::unregisterOption(Option* option)
 {
-    if (!option) return;
+    if (!option)
+    {
+        return;
+    }
 
     for (OptionsList::iterator it = d->options.begin();
          it != d->options.end(); )
@@ -183,7 +173,10 @@ void Parser::registerModifier(Modifier* modifier)
 
 void Parser::unregisterModifier(Modifier* modifier)
 {
-    if (!modifier) return;
+    if (!modifier)
+    {
+        return;
+    }
 
     for (ModifierList::iterator it = d->modifiers.begin();
          it != d->modifiers.end(); )
@@ -223,9 +216,6 @@ QString Parser::parse(ParseSettings& settings)
 
     ParseResults results;
 
-//    settings.startIndex   = d->globalSettings.startIndex;
-//    settings.currentIndex = d->counter++;
-
     foreach (Option* option, d->options)
     {
         ParseResults r = option->parse(settings);
