@@ -36,14 +36,14 @@
 
 // Local includes
 
-#include "parseobjectdialog.h"
+#include "parseabledialog.h"
 #include "ui_replacemodifierdialogwidget.h"
 
 namespace Digikam
 {
 
-ReplaceDialog::ReplaceDialog(ParseObject* parent)
-             : ParseObjectDialog(parent), ui(new Ui::ReplaceModifierDialogWidget())
+ReplaceDialog::ReplaceDialog(Parseable* parent)
+             : ParseableDialog(parent), ui(new Ui::ReplaceModifierDialogWidget())
 {
     QWidget* mainWidget = new QWidget(this);
     ui->setupUi(mainWidget);
@@ -65,7 +65,7 @@ ReplaceModifier::ReplaceModifier()
     addToken("{replace:\"||old||\", \"||new||\",||options||}",
              i18n("Replace text (||options||: ||r|| = regular expression, ||i|| = ignore case)"));
 
-    QRegExp reg("\\{replace:\"(.*)\",\"(.*)\"(,(r|ri|ir|i))?\\}");
+    QRegExp reg("\\{replace(:\"(.*)\",\"(.*)\"(,(r|ri|ir|i))?)\\}");
     reg.setMinimal(true);
     setRegExp(reg);
 }
@@ -108,15 +108,15 @@ void ReplaceModifier::slotTokenTriggered(const QString& token)
     emit signalTokenTriggered(result);
 }
 
-QString ReplaceModifier::modifyOperation(const ParseSettings& settings, const QString& str2Modify)
+QString ReplaceModifier::parseOperation(ParseSettings& settings)
 {
     Q_UNUSED(settings);
 
     const QRegExp& reg  = regExp();
-    QString original    = reg.cap(1);
-    QString replacement = reg.cap(2);
-    QString result      = str2Modify;
-    QString options     = reg.cap(4);
+    QString original    = reg.cap(2);
+    QString replacement = reg.cap(3);
+    QString result      = settings.str2Modify;
+    QString options     = reg.cap(5);
     Qt::CaseSensitivity caseType = (!options.isEmpty() && options.contains('i'))
                                    ? Qt::CaseInsensitive
                                    : Qt::CaseSensitive;
