@@ -27,7 +27,7 @@
 // Local includes
 
 #include "modifier.h"
-#include "parseobjectdialog.h"
+#include "parseabledialog.h"
 
 class KLineEdit;
 class QCheckBox;
@@ -40,13 +40,13 @@ namespace Ui
 namespace Digikam
 {
 
-class ReplaceDialog : public ParseObjectDialog
+class ReplaceDialog : public ParseableDialog
 {
     Q_OBJECT
 
 public:
 
-    ReplaceDialog(ParseObject* parent);
+    ReplaceDialog(Parseable* parent);
     ~ReplaceDialog();
 
     Ui::ReplaceModifierDialogWidget* const ui;
@@ -61,7 +61,7 @@ class ReplaceModifier : public Modifier
 public:
 
     ReplaceModifier();
-    virtual QString modifyOperation(const ParseSettings& settings, const QString& str2Modify);
+    virtual QString parseOperation(ParseSettings& settings);
 
 private Q_SLOTS:
 
