@@ -35,17 +35,18 @@ TrimmedModifier::TrimmedModifier()
                : Modifier(i18n("Trimmed"), i18n("Remove leading, trailing and extra whitespace"),
                           SmallIcon("edit-cut"))
 {
-    addToken("{trim}", description());
+    QString token = "{trim}";
+    addToken(token, description());
 
-    QRegExp reg("\\{trim\\}");
+    QRegExp reg(escapeToken(token));
     reg.setMinimal(true);
     setRegExp(reg);
 }
 
-QString TrimmedModifier::modifyOperation(const ParseSettings& settings, const QString& str2Modify)
+QString TrimmedModifier::parseOperation(ParseSettings& settings)
 {
     Q_UNUSED(settings);
-    return str2Modify.simplified();
+    return settings.str2Modify.simplified();
 }
 
 } // namespace Digikam
