@@ -132,7 +132,7 @@ using namespace KDcrawIface;
 namespace Digikam
 {
 
-CameraUI::CameraUI(QWidget* parent, const QString& cameraTitle,
+CameraUI::CameraUI(QWidget* const parent, const QString& cameraTitle,
                    const QString& model, const QString& port,
                    const QString& path, int startIndex)
         : KXmlGuiWindow(parent), d(new CameraUIPriv)
@@ -635,12 +635,6 @@ void CameraUI::setupConnections()
     connect(this, SIGNAL(signalWindowHasMoved()),
             d->zoomBar, SLOT(slotUpdateTrackerPos()));
 
-    connect(this, SIGNAL(signalWindowHasMoved()),
-            d->renameCustomizer, SLOT(slotUpdateTrackerPos()));
-
-    connect(this, SIGNAL(signalWindowLostFocus()),
-            d->renameCustomizer, SLOT(slotHideToolTipTracker()));
-
     // -------------------------------------------------------------------------
 
     connect(CollectionManager::instance(), SIGNAL(locationStatusChanged(const CollectionLocation &, int)),
@@ -868,19 +862,6 @@ void CameraUI::moveEvent(QMoveEvent *e)
     emit signalWindowHasMoved();
 }
 
-bool CameraUI::event(QEvent *e)
-{
-    switch (e->type())
-    {
-        case QEvent::WindowDeactivate:
-            emit signalWindowLostFocus();
-            break;
-        default:
-            break;
-    }
-    return KXmlGuiWindow::event(e);
-}
-
 void CameraUI::slotClose()
 {
 /*FIXME
@@ -2202,7 +2183,7 @@ void CameraUI::slotToggleFullScreen()
     {
         setWindowState( windowState() & ~Qt::WindowFullScreen ); // reset
 
-        menuBar()->show();
+        slotShowMenuBar();
         statusBar()->show();
         showToolBars();
 
@@ -2365,8 +2346,7 @@ void CameraUI::slotCollectionLocationStatusChanged(const CollectionLocation &, i
 
 void CameraUI::slotShowMenuBar()
 {
-    const bool visible = menuBar()->isVisible();
-    menuBar()->setVisible(!visible);
+    menuBar()->setVisible(d->showMenuBarAction->isChecked());
 }
 
 void CameraUI::slotSidebarTabTitleStyleChanged()
