@@ -79,26 +79,30 @@ class DImgInterfacePrivate
 
 public:
 
-    DImgInterfacePrivate()
+    DImgInterfacePrivate() :
+        valid(false),
+        rotatedOrFlipped(false),
+        exifOrient(false),
+        doSoftProofing(false),
+        width(0),
+        height(0),
+        origWidth(0),
+        origHeight(0),
+        selX(0),
+        selY(0),
+        selW(0),
+        selH(0),
+        gamma(0.0),
+        brightness(0.0),
+        contrast(0.0),
+        zoom(1.0),
+        displayingWidget(0),
+        undoMan(0),
+        cmSettings(0),
+        expoSettings(0),
+        thread(0)
+
     {
-        undoMan          = 0;
-        cmSettings       = 0;
-        expoSettings     = 0;
-        thread           = 0;
-        width            = 0;
-        height           = 0;
-        origWidth        = 0;
-        origHeight       = 0;
-        selX             = 0;
-        selY             = 0;
-        selW             = 0;
-        selH             = 0;
-        zoom             = 1.0;
-        displayingWidget = 0;
-        exifOrient       = false;
-        valid            = false;
-        rotatedOrFlipped = false;
-        doSoftProofing   = false;
     }
 
     bool                       valid;
@@ -1040,6 +1044,8 @@ QString DImgInterface::getImageFormat()
 
 QPixmap DImgInterface::convertToPixmap(DImg& img)
 {
+    QPixmap pix;
+
     if (d->cmSettings->enableCM && (d->cmSettings->useManagedView || d->doSoftProofing))
     {
         // dont use d->monitorICCtrans here, because img may have a different embedded profile
@@ -1051,10 +1057,24 @@ QPixmap DImgInterface::convertToPixmap(DImg& img)
         else
             transform = manager.displayTransform(d->displayingWidget);
 
-        return img.convertToPixmap(transform);
+        pix = img.convertToPixmap(transform);
+    }
+    else
+    {
+        pix = img.convertToPixmap();
     }
 
-    return img.convertToPixmap();
+    // Show the Over/Under exposure pixels indicators
+
+    if (d->expoSettings->underExposureIndicator || d->expoSettings->overExposureIndicator)
+    {
+        QPainter painter(&pix);
+        QImage pureColorMask = img.pureColorMask(d->expoSettings);
+        QPixmap pixMask      = QPixmap::fromImage(pureColorMask);
+        painter.drawPixmap(0, 0, pixMask, 0, 0, pixMask.width(), pixMask.height());
+    }
+
+    return pix;
 }
 
 }  // namespace Digikam
