@@ -46,7 +46,7 @@
 namespace Digikam
 {
 
-class EditorToolPriv
+class EditorTool::EditorToolPriv
 {
 
 public:
@@ -147,6 +147,9 @@ void EditorTool::setToolSettings(EditorToolSettings* settings)
 {
     d->settings = settings;
 
+    d->settings->setToolIcon(toolIcon());
+    d->settings->setToolName(toolName());
+
     connect(d->settings, SIGNAL(signalOkClicked()),
             this, SLOT(slotOk()));
 
@@ -279,7 +282,7 @@ void EditorTool::setToolInfoMessage(const QString& txt)
     EditorToolIface::editorToolIface()->setToolInfoMessage(txt);
 }
 
-void EditorTool::slotUpdateSpotInfo(const Digikam::DColor& col, const QPoint& point)
+void EditorTool::slotUpdateSpotInfo(const DColor& col, const QPoint& point)
 {
     DColor color = col;
     setToolInfoMessage(i18n("(%1,%2) RGBA:%3,%4,%5,%6",
@@ -290,7 +293,7 @@ void EditorTool::slotUpdateSpotInfo(const Digikam::DColor& col, const QPoint& po
 
 // ----------------------------------------------------------------
 
-class EditorToolThreadedPriv
+class EditorToolThreaded::EditorToolThreadedPriv
 {
 
 public:
@@ -302,16 +305,16 @@ public:
         currentRenderingMode = EditorToolThreaded::NoneRendering;
     }
 
-    bool                               delFilter;
+    bool                              delFilter;
 
-    EditorToolThreaded::RenderingMode  currentRenderingMode;
+    EditorToolThreaded::RenderingMode currentRenderingMode;
 
-    QString                            progressMess;
+    QString                           progressMess;
 
-    DImgThreadedFilter                *threadedFilter;
+    DImgThreadedFilter*               threadedFilter;
 };
 
-EditorToolThreaded::EditorToolThreaded(QObject *parent)
+EditorToolThreaded::EditorToolThreaded(QObject* parent)
                   : EditorTool(parent), d(new EditorToolThreadedPriv)
 {
 }
@@ -385,6 +388,9 @@ void EditorToolThreaded::slotAbort()
     toolSettings()->enableButton(EditorToolSettings::SaveAs,  true);
     toolSettings()->enableButton(EditorToolSettings::Try,     true);
     toolSettings()->enableButton(EditorToolSettings::Default, true);
+    toolView()->setEnabled(true);
+
+    kapp->restoreOverrideCursor();
 
     renderingFinished();
 }
@@ -467,6 +473,7 @@ void EditorToolThreaded::slotOk()
     toolSettings()->enableButton(EditorToolSettings::Load,    false);
     toolSettings()->enableButton(EditorToolSettings::Default, false);
     toolSettings()->enableButton(EditorToolSettings::Try,     false);
+    toolView()->setEnabled(false);
 
     EditorToolIface::editorToolIface()->setToolStartProgress(d->progressMess.isEmpty() ? toolName() : d->progressMess);
     kapp->setOverrideCursor( Qt::WaitCursor );
@@ -494,8 +501,10 @@ void EditorToolThreaded::slotEffect()
     toolSettings()->enableButton(EditorToolSettings::Load,    false);
     toolSettings()->enableButton(EditorToolSettings::Default, false);
     toolSettings()->enableButton(EditorToolSettings::Try,     false);
+    toolView()->setEnabled(false);
 
     EditorToolIface::editorToolIface()->setToolStartProgress(d->progressMess.isEmpty() ? toolName() : d->progressMess);
+    kapp->setOverrideCursor(Qt::WaitCursor);
 
     if (d->delFilter && d->threadedFilter)
     {
@@ -510,7 +519,6 @@ void EditorToolThreaded::slotCancel()
 {
     writeSettings();
     slotAbort();
-    kapp->restoreOverrideCursor();
     emit cancelClicked();
 }
 
