@@ -27,6 +27,7 @@
 
 #include <QButtonGroup>
 #include <QLabel>
+#include <QPixmap>
 #include <QLayout>
 #include <QMap>
 #include <QPair>
@@ -59,37 +60,42 @@
 #include "histogramwidget.h"
 #include "histogrambox.h"
 #include "globals.h"
+#include "themeengine.h"
 
 using namespace KDcrawIface;
 
 namespace Digikam
 {
 
-class EditorToolSettingsPriv
+class EditorToolSettings::EditorToolSettingsPriv
 {
 
 public:
 
-    EditorToolSettingsPriv()
+    EditorToolSettingsPriv() :
+        scaleBG(0),
+        linHistoButton(0),
+        logHistoButton(0),
+        settingsArea(0),
+        plainPage(0),
+        toolName(0),
+        toolIcon(0),
+        btnBox1(0),
+        btnBox2(0),
+        guideBox(0),
+        channelCB(0),
+        colorsCB(0),
+        okBtn(0),
+        cancelBtn(0),
+        tryBtn(0),
+        defaultBtn(0),
+        saveAsBtn(0),
+        loadBtn(0),
+        guideColorBt(0),
+        hGradient(0),
+        histogramBox(0),
+        guideSize(0)
     {
-        okBtn           = 0;
-        cancelBtn       = 0;
-        tryBtn          = 0;
-        defaultBtn      = 0;
-        settingsArea    = 0;
-        plainPage       = 0;
-        btnBox1         = 0;
-        btnBox2         = 0;
-        saveAsBtn       = 0;
-        loadBtn         = 0;
-        guideBox        = 0;
-        guideColorBt    = 0;
-        guideSize       = 0;
-        channelCB       = 0;
-        colorsCB        = 0;
-        scaleBG         = 0;
-        histogramBox    = 0;
-        hGradient       = 0;
     }
 
     QButtonGroup*        scaleBG;
@@ -100,6 +106,9 @@ public:
     QWidget*             settingsArea;
     QWidget*             plainPage;
 
+    QLabel*              toolName;
+    QLabel*              toolIcon;
+
     KHBox*               btnBox1;
     KHBox*               btnBox2;
     KHBox*               guideBox;
@@ -123,7 +132,7 @@ public:
     RIntNumInput*        guideSize;
 };
 
-EditorToolSettings::EditorToolSettings(QWidget *parent)
+EditorToolSettings::EditorToolSettings(QWidget* parent)
                   : QScrollArea(parent), d(new EditorToolSettingsPriv)
 {
     setFrameStyle( QFrame::NoFrame );
@@ -135,16 +144,51 @@ EditorToolSettings::EditorToolSettings(QWidget *parent)
 
     QGridLayout* gridSettings = new QGridLayout(d->settingsArea);
 
-    d->plainPage    = new QWidget(d->settingsArea);
-    d->guideBox     = new KHBox(d->settingsArea);
-    d->btnBox1      = new KHBox(d->settingsArea);
-    d->btnBox2      = new KHBox(d->settingsArea);
-    d->histogramBox = new HistogramBox(d->settingsArea);
+    d->plainPage      = new QWidget(d->settingsArea);
+    d->guideBox       = new KHBox(d->settingsArea);
+    d->btnBox1        = new KHBox(d->settingsArea);
+    d->btnBox2        = new KHBox(d->settingsArea);
+    d->histogramBox   = new HistogramBox(d->settingsArea);
+
+    // ---------------------------------------------------------------
+
+    QFrame* toolDescriptor = new QFrame(d->settingsArea);
+
+    d->toolName = new QLabel();
+    d->toolIcon = new QLabel();
+
+    QFont font = d->toolName->font();
+    font.setBold(true);
+    d->toolName->setFont(font);
+
+    QString frameStyle = QString("QFrame {"
+            "color: %1;"
+            "border: 1px solid %2;"
+            "border-radius: 5px;"
+            "background-color: %3;"
+            "}")
+            .arg(ThemeEngine::instance()->textSelColor().name())
+            .arg(ThemeEngine::instance()->textSelColor().name())
+            .arg(ThemeEngine::instance()->thumbSelColor().name());
+
+    QString noFrameStyle("QFrame {"
+            "border: none;"
+            "}");
+
+    toolDescriptor->setStyleSheet(frameStyle);
+    d->toolName->setStyleSheet(noFrameStyle);
+    d->toolIcon->setStyleSheet(noFrameStyle);
+
+    QGridLayout* descrLayout = new QGridLayout();
+    descrLayout->addWidget(d->toolIcon, 0, 0, 1, 1);
+    descrLayout->addWidget(d->toolName, 0, 1, 1, 1);
+    descrLayout->setColumnStretch(1, 10);
+    toolDescriptor->setLayout(descrLayout);
 
     // ---------------------------------------------------------------
 
     new QLabel(i18n("Guide:"), d->guideBox);
-    QLabel *space4  = new QLabel(d->guideBox);
+    QLabel* space4  = new QLabel(d->guideBox);
     d->guideColorBt = new KColorButton(QColor(Qt::red), d->guideBox);
     d->guideColorBt->setWhatsThis(i18n("Set here the color used to draw dashed guide lines."));
     d->guideSize    = new RIntNumInput(d->guideBox);
@@ -165,7 +209,7 @@ EditorToolSettings::EditorToolSettings(QWidget *parent)
     d->defaultBtn->setIcon(KIcon(SmallIcon("document-revert")));
     d->defaultBtn->setToolTip(i18n("Reset all settings to their default values."));
 
-    QLabel *space2 = new QLabel(d->btnBox1);
+    QLabel* space2 = new QLabel(d->btnBox1);
 
     d->okBtn = new KPushButton(d->btnBox1);
     d->okBtn->setGuiItem(KStandardGuiItem::ok());
@@ -190,7 +234,7 @@ EditorToolSettings::EditorToolSettings(QWidget *parent)
     d->saveAsBtn->setToolTip(i18n("Save all parameters to settings text file."));
 
 
-    QLabel *space3 = new QLabel(d->btnBox2);
+    QLabel* space3 = new QLabel(d->btnBox2);
 
     d->tryBtn = new KPushButton(d->btnBox2);
     d->tryBtn->setGuiItem(KStandardGuiItem::apply());
@@ -203,11 +247,12 @@ EditorToolSettings::EditorToolSettings(QWidget *parent)
 
     // ---------------------------------------------------------------
 
-    gridSettings->addWidget(d->histogramBox,   0, 0, 2, 2);
-    gridSettings->addWidget(d->plainPage,      3, 0, 1, 2);
-    gridSettings->addWidget(d->guideBox,       4, 0, 1, 2);
-    gridSettings->addWidget(d->btnBox2,        5, 0, 1, 2);
-    gridSettings->addWidget(d->btnBox1,        6, 0, 1, 2);
+    gridSettings->addWidget(toolDescriptor,    0, 0, 1,-1);
+    gridSettings->addWidget(d->histogramBox,   1, 0, 2, 2);
+    gridSettings->addWidget(d->plainPage,      4, 0, 1, 2);
+    gridSettings->addWidget(d->guideBox,       5, 0, 1, 2);
+    gridSettings->addWidget(d->btnBox2,        6, 0, 1, 2);
+    gridSettings->addWidget(d->btnBox1,        7, 0, 1, 2);
     gridSettings->setSpacing(spacingHint());
     gridSettings->setMargin(spacingHint());
 
@@ -268,9 +313,9 @@ QSize EditorToolSettings::minimumSizeHint() const
     // Set scroll area to a horizontal minimum size sufficient for the settings.
     // Do not touch vertical size hint.
     // Limit to 40% of the desktop width.
-    QSize hint = QScrollArea::minimumSizeHint();
+    QSize hint        = QScrollArea::minimumSizeHint();
     QRect desktopRect = KGlobalSettings::desktopGeometry(d->settingsArea);
-    int wSB = verticalScrollBar()->height();
+    int wSB           = verticalScrollBar()->height();
     hint.setWidth(qMin(d->settingsArea->minimumSizeHint().width() + wSB, desktopRect.width() * 2 / 5));
     return hint;
 }
@@ -285,7 +330,7 @@ int EditorToolSettings::spacingHint()
     return KDialog::spacingHint();
 }
 
-QWidget *EditorToolSettings::plainPage() const
+QWidget* EditorToolSettings::plainPage() const
 {
     return d->plainPage;
 }
@@ -320,7 +365,7 @@ KPushButton* EditorToolSettings::button(int buttonCode) const
 
 void EditorToolSettings::enableButton(int buttonCode, bool state)
 {
-    KPushButton *btn = button(buttonCode);
+    KPushButton* btn = button(buttonCode);
     if (btn) btn->setEnabled(state);
 }
 
@@ -368,4 +413,14 @@ void EditorToolSettings::setHistogramType(HistogramBoxType type)
     d->histogramBox->setHistogramType(type);
 }
 
+void EditorToolSettings::setToolIcon(const QPixmap& pixmap)
+{
+    d->toolIcon->setPixmap(pixmap);
+}
+
+void EditorToolSettings::setToolName(const QString& name)
+{
+    d->toolName->setText(name);
+}
+
 } // namespace Digikam
