@@ -588,7 +588,7 @@ void EditorWindow::setupStandardActions()
 
 void EditorWindow::setupStatusBar()
 {
-    m_nameLabel = new StatusProgressBar(statusBar());
+    m_nameLabel  = new StatusProgressBar(statusBar());
     m_nameLabel->setAlignment(Qt::AlignCenter);
     statusBar()->addWidget(m_nameLabel, 100);
 
@@ -623,21 +623,24 @@ void EditorWindow::setupStatusBar()
             this, SIGNAL(signalPreviewModeChanged(int)));
 
     QWidget* buttonsBox      = new QWidget(statusBar());
-    QHBoxLayout *hlay        = new QHBoxLayout(buttonsBox);
-    QButtonGroup *buttonsGrp = new QButtonGroup(buttonsBox);
+    QHBoxLayout* hlay        = new QHBoxLayout(buttonsBox);
+    QButtonGroup* buttonsGrp = new QButtonGroup(buttonsBox);
     buttonsGrp->setExclusive(false);
 
     d->underExposureIndicator = new QToolButton(buttonsBox);
     d->underExposureIndicator->setDefaultAction(d->viewUnderExpoAction);
+    d->underExposureIndicator->setFocusPolicy(Qt::NoFocus);
 //    new ButtonIconDisabler(d->underExposureIndicator);
 
     d->overExposureIndicator  = new QToolButton(buttonsBox);
     d->overExposureIndicator->setDefaultAction(d->viewOverExpoAction);
+    d->overExposureIndicator->setFocusPolicy(Qt::NoFocus);
 //    new ButtonIconDisabler(d->overExposureIndicator);
 
     d->cmViewIndicator        = new QToolButton(buttonsBox);
     d->cmViewIndicator->setDefaultAction(d->viewCMViewAction);
-//    new ButtonIconDisabler(d->cmViewIndicator);
+    d->cmViewIndicator->setFocusPolicy(Qt::NoFocus);
+    //    new ButtonIconDisabler(d->cmViewIndicator);
 
     buttonsGrp->addButton(d->underExposureIndicator);
     buttonsGrp->addButton(d->overExposureIndicator);
@@ -919,6 +922,8 @@ void EditorWindow::applyStandardSettings()
     m_IOFileSettings->useRAWImport = group.readEntry(d->configUseRawImportToolEntry, false);
     m_IOFileSettings->rawDecodingSettings.readSettings(group);
 
+    // -- Color Management settings ---------------------------------------------------------
+
     // If digiKam Color Management is enable, no need to correct color of decoded RAW image,
     // else, sRGB color workspace will be used.
 
@@ -939,6 +944,8 @@ void EditorWindow::applyStandardSettings()
         m_IOFileSettings->rawDecodingSettings.outputColorSpace = DRawDecoding::SRGB;
     }
 
+    d->toolIface->updateICCSettings();
+
     // -- GUI Settings -------------------------------------------------------
 
     d->legacyUpdateSplitterState(group);
@@ -951,13 +958,16 @@ void EditorWindow::applyStandardSettings()
 
     // -- Exposure Indicators Settings ---------------------------------------
 
-    d->exposureSettings->underExposureColor = group.readEntry(d->configUnderExposureColorEntry, QColor(Qt::white));
-    d->exposureSettings->overExposureColor  = group.readEntry(d->configOverExposureColorEntry, QColor(Qt::black));
+    d->exposureSettings->underExposureColor    = group.readEntry(d->configUnderExposureColorEntry,    QColor(Qt::white));
+    d->exposureSettings->underExposurePercent  = group.readEntry(d->configUnderExposurePercentsEntry, 1.0);
+    d->exposureSettings->overExposureColor     = group.readEntry(d->configOverExposureColorEntry,     QColor(Qt::black));
+    d->exposureSettings->overExposurePercent   = group.readEntry(d->configOverExposurePercentsEntry,  1.0);
+    d->exposureSettings->exposureIndicatorMode = group.readEntry(d->configExpoIndicatorModeEntry,     true);
+    d->toolIface->updateExposureSettings();
 }
 
 void EditorWindow::saveStandardSettings()
 {
-
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(CONFIG_GROUP_NAME);
 
@@ -973,7 +983,6 @@ void EditorWindow::saveStandardSettings()
     d->previewToolBar->writeSettings(group);
 
     config->sync();
-
 }
 
 /** Method used by Editor Tools. Only tools based on imageregionwidget support zoomming.
@@ -1938,7 +1947,19 @@ void EditorWindow::moveFile()
     {
         kDebug() << "moving a local file";
 
-        QByteArray dstFileName = QFile::encodeName(m_savingContext->destinationURL.toLocalFile());
+        QString fileName = m_savingContext->destinationURL.toLocalFile();
+
+        // check that we're not replacing a symlink
+        QFileInfo info(fileName);
+        if (info.isSymLink())
+        {
+            fileName = info.symLinkTarget();
+            kDebug() << "Target filePath" << m_savingContext->destinationURL.toLocalFile()
+                     << "is a symlink pointing to"
+                     << fileName << ". Storing image there.";
+        }
+
+        QByteArray dstFileName = QFile::encodeName(fileName);
 #ifndef _WIN32
         // Store old permissions:
         // Just get the current umask.
@@ -1965,7 +1986,7 @@ void EditorWindow::moveFile()
         // KDE 4.3.0
         // KDE::rename() takes care of QString -> bytestring encoding
         ret = KDE::rename(m_savingContext->saveTempFileName,
-                           m_savingContext->destinationURL.toLocalFile());
+                          fileName);
 #else
         // KDE 4.2.x or 4.1.x
         ret = KDE_rename(QFile::encodeName(m_savingContext->saveTempFileName),
@@ -2126,8 +2147,8 @@ void EditorWindow::slotContribute()
 void EditorWindow::slotToggleSlideShow()
 {
     KSharedConfig::Ptr config = KGlobal::config();
-    KConfigGroup group = config->group(CONFIG_GROUP_NAME);
-    bool startWithCurrent = group.readEntry(d->configSlideShowStartCurrentEntry, false);
+    KConfigGroup group        = config->group(CONFIG_GROUP_NAME);
+    bool startWithCurrent     = group.readEntry(d->configSlideShowStartCurrentEntry, false);
 
     SlideShowSettings settings;
     settings.delay                = group.readEntry(d->configSlideShowDelayEntry, 5) * 1000;
