@@ -35,6 +35,10 @@
 #include <kconfiggroup.h>
 #include <kdebug.h>
 
+// Local includes
+
+#include "editorwindow.h"
+
 class QDialog;
 class QEventLoop;
 class QLabel;
@@ -56,45 +60,12 @@ class ExposureSettingsContainer;
 class ICCSettingsContainer;
 class PreviewToolBar;
 
-class EditorWindowPriv
+class EditorWindow::EditorWindowPriv
 {
 
 public:
 
     EditorWindowPriv() :
-        configAutoZoomEntry("AutoZoom"),
-        configBackgroundColorEntry("BackgroundColor"),
-        configFullScreenEntry("FullScreen"),
-        configFullScreenHideThumbBarEntry("FullScreenHideThumbBar"),
-        configFullScreenHideToolBarEntry("FullScreen Hide ToolBar"),
-        configJpeg2000CompressionEntry("JPEG2000Compression"),
-        configJpeg2000LossLessEntry("JPEG2000LossLess"),
-        configJpegCompressionEntry("JPEGCompression"),
-        configJpegSubSamplingEntry("JPEGSubSampling"),
-        configOverExposureColorEntry("OverExposureColor"),
-        configOverExposureIndicatorEntry("OverExposureIndicator"),
-        configPgfCompressionEntry("PGFCompression"),
-        configPgfLossLessEntry("PGFLossLess"),
-        configPngCompressionEntry("PNGCompression"),
-        configSlideShowDelayEntry("SlideShowDelay"),
-        configSlideShowLoopEntry("SlideShowLoop"),
-        configSlideShowPrintApertureFocalEntry("SlideShowPrintApertureFocal"),
-        configSlideShowPrintCommentEntry("SlideShowPrintComment"),
-        configSlideShowPrintDateEntry("SlideShowPrintDate"),
-        configSlideShowPrintExpoSensitivityEntry("SlideShowPrintExpoSensitivity"),
-        configSlideShowPrintMakeModelEntry("SlideShowPrintMakeModel"),
-        configSlideShowPrintNameEntry("SlideShowPrintName"),
-        configSlideShowPrintRatingEntry("SlideShowPrintRating"),
-        configSlideShowStartCurrentEntry("SlideShowStartCurrent"),
-        configSplitterStateEntry("SplitterState"),
-        configTiffCompressionEntry("TIFFCompression"),
-        configUnderExposureColorEntry("UnderExposureColor"),
-        configUnderExposureIndicatorEntry("UnderExposureIndicator"),
-        configUseRawImportToolEntry("UseRawImportTool"),
-        configUseThemeBackgroundColorEntry("UseThemeBackgroundColor"),
-        configVerticalSplitterSizesEntry("Vertical Splitter Sizes"),
-        configVerticalSplitterStateEntry("Vertical Splitter State"),
-
         removeFullScreenButton(false),
         fullScreenHideToolBar(false),
 
@@ -147,7 +118,6 @@ public:
         exposureSettings(0),
 
         toolIface(0)
-
     {
     }
 
@@ -155,38 +125,41 @@ public:
     {
     }
 
-    QString                    configAutoZoomEntry;
-    QString                    configBackgroundColorEntry;
-    QString                    configFullScreenEntry;
-    QString                    configFullScreenHideThumbBarEntry;
-    QString                    configFullScreenHideToolBarEntry;
-    QString                    configJpeg2000CompressionEntry;
-    QString                    configJpeg2000LossLessEntry;
-    QString                    configJpegCompressionEntry;
-    QString                    configJpegSubSamplingEntry;
-    QString                    configOverExposureColorEntry;
-    QString                    configOverExposureIndicatorEntry;
-    QString                    configPgfCompressionEntry;
-    QString                    configPgfLossLessEntry;
-    QString                    configPngCompressionEntry;
-    QString                    configSlideShowDelayEntry;
-    QString                    configSlideShowLoopEntry;
-    QString                    configSlideShowPrintApertureFocalEntry;
-    QString                    configSlideShowPrintCommentEntry;
-    QString                    configSlideShowPrintDateEntry;
-    QString                    configSlideShowPrintExpoSensitivityEntry;
-    QString                    configSlideShowPrintMakeModelEntry;
-    QString                    configSlideShowPrintNameEntry;
-    QString                    configSlideShowPrintRatingEntry;
-    QString                    configSlideShowStartCurrentEntry;
-    QString                    configSplitterStateEntry;
-    QString                    configTiffCompressionEntry;
-    QString                    configUnderExposureColorEntry;
-    QString                    configUnderExposureIndicatorEntry;
-    QString                    configUseRawImportToolEntry;
-    QString                    configUseThemeBackgroundColorEntry;
-    QString                    configVerticalSplitterSizesEntry;
-    QString                    configVerticalSplitterStateEntry;
+    static const QString       configAutoZoomEntry;
+    static const QString       configBackgroundColorEntry;
+    static const QString       configFullScreenEntry;
+    static const QString       configFullScreenHideThumbBarEntry;
+    static const QString       configFullScreenHideToolBarEntry;
+    static const QString       configJpeg2000CompressionEntry;
+    static const QString       configJpeg2000LossLessEntry;
+    static const QString       configJpegCompressionEntry;
+    static const QString       configJpegSubSamplingEntry;
+    static const QString       configPgfCompressionEntry;
+    static const QString       configPgfLossLessEntry;
+    static const QString       configPngCompressionEntry;
+    static const QString       configSlideShowDelayEntry;
+    static const QString       configSlideShowLoopEntry;
+    static const QString       configSlideShowPrintApertureFocalEntry;
+    static const QString       configSlideShowPrintCommentEntry;
+    static const QString       configSlideShowPrintDateEntry;
+    static const QString       configSlideShowPrintExpoSensitivityEntry;
+    static const QString       configSlideShowPrintMakeModelEntry;
+    static const QString       configSlideShowPrintNameEntry;
+    static const QString       configSlideShowPrintRatingEntry;
+    static const QString       configSlideShowStartCurrentEntry;
+    static const QString       configSplitterStateEntry;
+    static const QString       configTiffCompressionEntry;
+    static const QString       configUnderExposureColorEntry;
+    static const QString       configUnderExposureIndicatorEntry;
+    static const QString       configUnderExposurePercentsEntry;
+    static const QString       configOverExposureColorEntry;
+    static const QString       configOverExposureIndicatorEntry;
+    static const QString       configOverExposurePercentsEntry;
+    static const QString       configExpoIndicatorModeEntry;
+    static const QString       configUseRawImportToolEntry;
+    static const QString       configUseThemeBackgroundColorEntry;
+    static const QString       configVerticalSplitterSizesEntry;
+    static const QString       configVerticalSplitterStateEntry;
 
     bool                       removeFullScreenButton;
     bool                       fullScreenHideToolBar;
@@ -295,6 +268,41 @@ public:
     }
 
 };
+const QString EditorWindow::EditorWindowPriv::configAutoZoomEntry("AutoZoom");
+const QString EditorWindow::EditorWindowPriv::configBackgroundColorEntry("BackgroundColor");
+const QString EditorWindow::EditorWindowPriv::configFullScreenEntry("FullScreen");
+const QString EditorWindow::EditorWindowPriv::configFullScreenHideThumbBarEntry("FullScreenHideThumbBar");
+const QString EditorWindow::EditorWindowPriv::configFullScreenHideToolBarEntry("FullScreen Hide ToolBar");
+const QString EditorWindow::EditorWindowPriv::configJpeg2000CompressionEntry("JPEG2000Compression");
+const QString EditorWindow::EditorWindowPriv::configJpeg2000LossLessEntry("JPEG2000LossLess");
+const QString EditorWindow::EditorWindowPriv::configJpegCompressionEntry("JPEGCompression");
+const QString EditorWindow::EditorWindowPriv::configJpegSubSamplingEntry("JPEGSubSampling");
+const QString EditorWindow::EditorWindowPriv::configPgfCompressionEntry("PGFCompression");
+const QString EditorWindow::EditorWindowPriv::configPgfLossLessEntry("PGFLossLess");
+const QString EditorWindow::EditorWindowPriv::configPngCompressionEntry("PNGCompression");
+const QString EditorWindow::EditorWindowPriv::configSlideShowDelayEntry("SlideShowDelay");
+const QString EditorWindow::EditorWindowPriv::configSlideShowLoopEntry("SlideShowLoop");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintApertureFocalEntry("SlideShowPrintApertureFocal");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintCommentEntry("SlideShowPrintComment");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintDateEntry("SlideShowPrintDate");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintExpoSensitivityEntry("SlideShowPrintExpoSensitivity");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintMakeModelEntry("SlideShowPrintMakeModel");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintNameEntry("SlideShowPrintName");
+const QString EditorWindow::EditorWindowPriv::configSlideShowPrintRatingEntry("SlideShowPrintRating");
+const QString EditorWindow::EditorWindowPriv::configSlideShowStartCurrentEntry("SlideShowStartCurrent");
+const QString EditorWindow::EditorWindowPriv::configSplitterStateEntry("SplitterState");
+const QString EditorWindow::EditorWindowPriv::configTiffCompressionEntry("TIFFCompression");
+const QString EditorWindow::EditorWindowPriv::configUnderExposureColorEntry("UnderExposureColor");
+const QString EditorWindow::EditorWindowPriv::configUnderExposureIndicatorEntry("UnderExposureIndicator");
+const QString EditorWindow::EditorWindowPriv::configUnderExposurePercentsEntry("UnderExposurePercentsEntry");
+const QString EditorWindow::EditorWindowPriv::configOverExposureColorEntry("OverExposureColor");
+const QString EditorWindow::EditorWindowPriv::configOverExposureIndicatorEntry("OverExposureIndicator");
+const QString EditorWindow::EditorWindowPriv::configOverExposurePercentsEntry("OverExposurePercentsEntry");
+const QString EditorWindow::EditorWindowPriv::configExpoIndicatorModeEntry("ExpoIndicatorMode");
+const QString EditorWindow::EditorWindowPriv::configUseRawImportToolEntry("UseRawImportTool");
+const QString EditorWindow::EditorWindowPriv::configUseThemeBackgroundColorEntry("UseThemeBackgroundColor");
+const QString EditorWindow::EditorWindowPriv::configVerticalSplitterSizesEntry("Vertical Splitter Sizes");
+const QString EditorWindow::EditorWindowPriv::configVerticalSplitterStateEntry("Vertical Splitter State");
 
 }  // namespace Digikam
 
