@@ -124,27 +124,26 @@ class ImageWindowPriv
 
 public:
 
-    ImageWindowPriv()
+    ImageWindowPriv() :
+        allowSaving(true),
+        star0(0),
+        star1(0),
+        star2(0),
+        star3(0),
+        star4(0),
+        star5(0),
+        fileDeletePermanentlyAction(0),
+        fileDeletePermanentlyDirectlyAction(0),
+        fileTrashDirectlyAction(0),
+        dbStatAction(0),
+        thumbBar(0),
+        thumbBarDock(0),
+        rightSideBar(0)
     {
-        configShowThumbbarEntry             = "Show Thumbbar";
-        configHorizontalThumbbarEntry       = "HorizontalThumbbar";
-        allowSaving                         = true;
-        star0                               = 0;
-        star1                               = 0;
-        star2                               = 0;
-        star3                               = 0;
-        star4                               = 0;
-        star5                               = 0;
-        fileDeletePermanentlyAction         = 0;
-        fileDeletePermanentlyDirectlyAction = 0;
-        fileTrashDirectlyAction             = 0;
-        rightSideBar                        = 0;
-        thumbBar                            = 0;
-        thumbBarDock                        = 0;
     }
 
-    QString                   configShowThumbbarEntry;
-    QString                   configHorizontalThumbbarEntry;
+    static const QString      configShowThumbbarEntry;
+    static const QString      configHorizontalThumbbarEntry;
 
     // If image editor is launched by camera interface, current
     // image cannot be saved.
@@ -176,6 +175,8 @@ public:
 
     ImagePropertiesSideBarDB* rightSideBar;
 };
+const QString ImageWindowPriv::configShowThumbbarEntry("Show Thumbbar");
+const QString ImageWindowPriv::configHorizontalThumbbarEntry("HorizontalThumbbar");
 
 ImageWindow* ImageWindow::m_instance = 0;
 
@@ -834,18 +835,28 @@ void ImageWindow::slotAssignRatingFiveStar()
 }
 
 void ImageWindow::slotAssignRating(int rating)
+{
+    assignRating(d->imageInfoCurrent, rating);
+}
+
+void ImageWindow::assignRating(const ImageInfo& info, int rating)
 {
     rating = qMin(RatingMax, qMax(RatingMin, rating));
-    if (!d->imageInfoCurrent.isNull())
+    if (!info.isNull())
     {
         MetadataHub hub;
-        hub.load(d->imageInfoCurrent);
+        hub.load(info);
         hub.setRating(rating);
-        hub.write(d->imageInfoCurrent, MetadataHub::PartialWrite);
-        hub.write(d->imageInfoCurrent.filePath(), MetadataHub::FullWriteIfChanged);
+        hub.write(info, MetadataHub::PartialWrite);
+        hub.write(info.filePath(), MetadataHub::FullWriteIfChanged);
     }
 }
 
+void ImageWindow::slotRatingChanged(const KUrl& url, int rating)
+{
+    assignRating(ImageInfo(url), rating);
+}
+
 void ImageWindow::slotUpdateItemInfo()
 {
     int index = d->urlList.indexOf(d->urlCurrent);
@@ -1344,10 +1355,13 @@ void ImageWindow::slideShow(bool startWithCurrent, SlideShowSettings& settings)
         settings.exifRotate = AlbumSettings::instance()->getExifRotate();
         settings.fileList   = d->urlList;
 
-        SlideShow *slide = new SlideShow(settings);
+        SlideShow* slide = new SlideShow(settings);
         if (startWithCurrent)
             slide->setCurrent(d->urlCurrent);
 
+        connect(slide, SIGNAL(signalRatingChanged(const KUrl&, int)),
+                this, SLOT(slotRatingChanged(const KUrl&, int)));
+
         slide->show();
     }
 }
