@@ -6,7 +6,7 @@
  * Date        : 2007-03-05
  * Description : digiKam light table GUI
  *
- * Copyright (C) 2007-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,7 +45,6 @@ namespace Digikam
 {
 
 class SlideShowSettings;
-class LightTableWindowPriv;
 
 class LightTableWindow : public KXmlGuiWindow
 {
@@ -55,7 +54,7 @@ public:
 
     ~LightTableWindow();
 
-    static LightTableWindow *lightTableWindow();
+    static LightTableWindow* lightTableWindow();
     static bool              lightTableWindowCreated();
 
     void loadImageInfos(const ImageInfoList& list, const ImageInfo& imageInfoCurrent, bool addTo);
@@ -75,7 +74,7 @@ public Q_SLOTS:
 
 protected:
 
-    void moveEvent(QMoveEvent *e);
+    void moveEvent(QMoveEvent* e);
 
 private:
 
@@ -106,8 +105,8 @@ private Q_SLOTS:
 
     void slotSetItemLeft();
     void slotSetItemRight();
-    void slotSetItemOnLeftPanel(const ImageInfo &);
-    void slotSetItemOnRightPanel(const ImageInfo &);
+    void slotSetItemOnLeftPanel(const ImageInfo&);
+    void slotSetItemOnRightPanel(const ImageInfo&);
     void slotLeftDroppedItems(const ImageInfoList&);
     void slotRightDroppedItems(const ImageInfoList&);
 
@@ -141,9 +140,6 @@ private Q_SLOTS:
 
     void slotThumbbarDroppedItems(const ImageInfoList&);
 
-    void slotZoomTo100Percents();
-    void slotFitToWindow();
-
     void slotProgressBarCancelButtonPressed();
     void slotToggleSlideShow();
     void slotToggleFullScreen();
@@ -167,9 +163,10 @@ private Q_SLOTS:
 
 private:
 
+    class LightTableWindowPriv;
     LightTableWindowPriv* const d;
 
-    static LightTableWindow *m_instance;
+    static LightTableWindow* m_instance;
 };
 
 }  // namespace Digikam
