@@ -66,6 +66,7 @@ public:
     bool                      cancel;
     bool                      last;
 
+    QString                   errorMessage;
     QString                   toolTitle;          // User friendly tool title.
     QString                   toolDescription;    // User friendly tool description.
 
@@ -120,7 +121,7 @@ BatchTool::BatchTool(const QString& name, BatchToolGroup group, QObject* parent)
     // NOTE: see B.K.O #209225 : signal/slot connection used internally to prevent crash when settings
     // are assigned to settings widget by main thread to tool thread.
 
-    connect(this, SIGNAL(signalSettingsChanged(const BatchToolSettings&)),
+    connect(this, SIGNAL(signalAssignSettings2Widget()),
             this, SLOT(slotAssignSettings2Widget()));
 }
 
@@ -131,6 +132,16 @@ BatchTool::~BatchTool()
     delete d;
 }
 
+QString BatchTool::errorDescription() const
+{
+    return d->errorMessage;
+}
+
+void BatchTool::setErrorDescription(const QString& errmsg)
+{
+    d->errorMessage = errmsg;
+}
+
 BatchTool::BatchToolGroup BatchTool::toolGroup() const
 {
     return d->toolGroup;
@@ -199,6 +210,7 @@ void BatchTool::slotSettingsChanged(const BatchToolSettings& settings)
 void BatchTool::setSettings(const BatchToolSettings& settings)
 {
     d->settings = settings;
+    emit signalAssignSettings2Widget();
 }
 
 void BatchTool::setInputUrl(const KUrl& inputUrl)
@@ -281,12 +293,12 @@ void BatchTool::cancel()
     d->cancel = true;
 }
 
-bool BatchTool::isCancelled()
+bool BatchTool::isCancelled() const
 {
     return d->cancel;
 }
 
-BatchToolSettings BatchTool::settings()
+BatchToolSettings BatchTool::settings() const
 {
     return d->settings;
 }
@@ -326,21 +338,21 @@ void BatchTool::setOutputUrlFromInputUrl()
     }
 }
 
-bool BatchTool::loadToDImg()
+bool BatchTool::loadToDImg() const
 {
     if (!d->image.isNull()) return true;
 
     return d->image.load(inputUrl().toLocalFile(), d->observer, getRawDecodingSettings());
 }
 
-bool BatchTool::savefromDImg()
+bool BatchTool::savefromDImg() const
 {
     if (!isLastChainedTool() && outputSuffix().isEmpty()) return true;
 
     DImg::FORMAT detectedFormat = d->image.detectedFormat();
-    QString frm = outputSuffix().toUpper();
-    bool resetOrientation = getResetExifOrientationAllowed()
-                    && (getNeedResetExifOrientation() || detectedFormat == DImg::RAW);
+    QString frm                 = outputSuffix().toUpper();
+    bool resetOrientation       = getResetExifOrientationAllowed() &&
+                                  (getNeedResetExifOrientation() || detectedFormat == DImg::RAW);
     if (frm.isEmpty())
     {
         // In case of output support is not set for ex. with all tool which do not convert to new format.
@@ -354,7 +366,7 @@ bool BatchTool::savefromDImg()
     return b;
 }
 
-DImg& BatchTool::image()
+DImg& BatchTool::image() const
 {
     return d->image;
 }
