@@ -6,7 +6,7 @@
  * Date        : 2009-03-03
  * Description : queue tool tip
  *
- * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,7 +43,7 @@
 namespace Digikam
 {
 
-class QueueToolTipPriv
+class QueueToolTip::QueueToolTipPriv
 {
 public:
 
